"""
Python module generated from Java source file org.yaml.snakeyaml.introspector.Property

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.introspector import *
from typing import Any, Callable, Iterable, Tuple


class Property(Comparable):
    """
    
    A `Property` represents a single member variable of a class, possibly including its
    accessor methods (getX, setX). The name stored in this class is the actual name of the property
    as given for the class, not an alias.
    
    
    
    Objects of this class have a total ordering which defaults to ordering based on the name of the
    property.
    """

    def __init__(self, name: str, type: type[Any]):
        ...


    def getType(self) -> type[Any]:
        ...


    def getActualTypeArguments(self) -> list[type[Any]]:
        ...


    def getName(self) -> str:
        ...


    def toString(self) -> str:
        ...


    def compareTo(self, o: "Property") -> int:
        ...


    def isWritable(self) -> bool:
        ...


    def isReadable(self) -> bool:
        ...


    def set(self, object: "Object", value: "Object") -> None:
        ...


    def get(self, object: "Object") -> "Object":
        ...


    def getAnnotations(self) -> list["Annotation"]:
        """
        Returns the annotations that are present on this property or empty `List` if there're no
        annotations.

        Returns
        - the annotations that are present on this property or empty `List` if there're no
                annotations
        """
        ...


    def getAnnotation(self, annotationType: type["A"]) -> "A":
        """
        Returns property's annotation for the given type or `null` if it's not present.
        
        Type `<A>`: class of the annotation

        Arguments
        - annotationType: the type of the annotation to be returned

        Returns
        - property's annotation for the given type or `null` if it's not present
        """
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, other: "Object") -> bool:
        ...



"""
Python module generated from Java source file com.google.common.cache.CacheBuilderSpec

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.base import MoreObjects
from com.google.common.base import Objects
from com.google.common.base import Splitter
from com.google.common.cache import *
from com.google.common.cache.LocalCache import Strength
from com.google.common.collect import ImmutableList
from com.google.common.collect import ImmutableMap
from java.util import Locale
from java.util.concurrent import TimeUnit
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class CacheBuilderSpec:
    """
    A specification of a CacheBuilder configuration.
    
    `CacheBuilderSpec` supports parsing configuration off of a string, which makes it
    especially useful for command-line configuration of a `CacheBuilder`.
    
    The string syntax is a series of comma-separated keys or key-value pairs, each corresponding
    to a `CacheBuilder` method.
    
    
      - `concurrencyLevel=[integer]`: sets CacheBuilder.concurrencyLevel.
      - `initialCapacity=[integer]`: sets CacheBuilder.initialCapacity.
      - `maximumSize=[long]`: sets CacheBuilder.maximumSize.
      - `maximumWeight=[long]`: sets CacheBuilder.maximumWeight.
      - `expireAfterAccess=[duration]`: sets CacheBuilder.expireAfterAccess.
      - `expireAfterWrite=[duration]`: sets CacheBuilder.expireAfterWrite.
      - `refreshAfterWrite=[duration]`: sets CacheBuilder.refreshAfterWrite.
      - `weakKeys`: sets CacheBuilder.weakKeys.
      - `softValues`: sets CacheBuilder.softValues.
      - `weakValues`: sets CacheBuilder.weakValues.
      - `recordStats`: sets CacheBuilder.recordStats.
    
    
    The set of supported keys will grow as `CacheBuilder` evolves, but existing keys will
    never be removed.
    
    Durations are represented by an integer, followed by one of "d", "h", "m", or "s",
    representing days, hours, minutes, or seconds respectively. (There is currently no syntax to
    request expiration in milliseconds, microseconds, or nanoseconds.)
    
    Whitespace before and after commas and equal signs is ignored. Keys may not be repeated; it is
    also illegal to use the following pairs of keys in a single value:
    
    
      - `maximumSize` and `maximumWeight`
      - `softValues` and `weakValues`
    
    
    `CacheBuilderSpec` does not support configuring `CacheBuilder` methods with
    non-value parameters. These must be configured in code.
    
    A new `CacheBuilder` can be instantiated from a `CacheBuilderSpec` using CacheBuilder.from(CacheBuilderSpec) or CacheBuilder.from(String).

    Author(s)
    - Adam Winer

    Since
    - 12.0
    """

    @staticmethod
    def parse(cacheBuilderSpecification: str) -> "CacheBuilderSpec":
        """
        Creates a CacheBuilderSpec from a string.

        Arguments
        - cacheBuilderSpecification: the string form
        """
        ...


    @staticmethod
    def disableCaching() -> "CacheBuilderSpec":
        """
        Returns a CacheBuilderSpec that will prevent caching.
        """
        ...


    def toParsableString(self) -> str:
        """
        Returns a string that can be used to parse an equivalent `CacheBuilderSpec`. The order
        and form of this representation is not guaranteed, except that reparsing its output will
        produce a `CacheBuilderSpec` equal to this instance.
        """
        ...


    def toString(self) -> str:
        """
        Returns a string representation for this CacheBuilderSpec instance. The form of this
        representation is not guaranteed.
        """
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, obj: "Object") -> bool:
        ...



"""
Python module generated from Java source file org.bukkit.WorldType

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import Maps
from enum import Enum
from java.util import Locale
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class WorldType(Enum):
    """
    Represents various types of worlds that may exist
    """

    NORMAL = ("DEFAULT")
    FLAT = ("FLAT")
    LARGE_BIOMES = ("LARGEBIOMES")
    AMPLIFIED = ("AMPLIFIED")


    def getName(self) -> str:
        """
        Gets the name of this WorldType

        Returns
        - Name of this type
        """
        ...


    @staticmethod
    def getByName(name: str) -> "WorldType":
        """
        Gets a WorldType by its name

        Arguments
        - name: Name of the WorldType to get

        Returns
        - Requested WorldType, or null if not found
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.CompactHashing

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.base import Objects
from com.google.common.collect import *
from com.google.common.primitives import Ints
from java.util import Arrays
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class CompactHashing:
    """
    Helper classes and static methods for implementing compact hash-based collections.

    Author(s)
    - Jon Noack
    """





"""
Python module generated from Java source file com.google.common.graph.ImmutableNetwork

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.base import Function
from com.google.common.collect import ImmutableMap
from com.google.common.collect import Maps
from com.google.common.graph import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import Immutable
from typing import Any, Callable, Iterable, Tuple


class ImmutableNetwork(StandardNetwork):
    """
    A Network whose elements and structural relationships will never change. Instances of
    this class may be obtained with .copyOf(Network).
    
    See the Guava User's Guide's <a
    href="https://github.com/google/guava/wiki/GraphsExplained#immutable-implementations">discussion
    of the `Immutable*` types</a> for more information on the properties and guarantees
    provided by this class.
    
    Type `<N>`: Node parameter type
    
    Type `<E>`: Edge parameter type

    Author(s)
    - Jens Nyman

    Since
    - 20.0
    """

    @staticmethod
    def copyOf(network: "Network"["N", "E"]) -> "ImmutableNetwork"["N", "E"]:
        """
        Returns an immutable copy of `network`.
        """
        ...


    @staticmethod
    def copyOf(network: "ImmutableNetwork"["N", "E"]) -> "ImmutableNetwork"["N", "E"]:
        """
        Simply returns its argument.

        Deprecated
        - no need to use this
        """
        ...


    def asGraph(self) -> "ImmutableGraph"["N"]:
        ...


    class Builder:
        """
        A builder for creating ImmutableNetwork instances, especially `static final`
        networks. Example:
        
        ````static final ImmutableNetwork<City, Train> TRAIN_NETWORK =
            NetworkBuilder.undirected()
                .allowsParallelEdges(True)
                .<City, Train>immutable()
                .addEdge(PARIS, BRUSSELS, Thalys.trainNumber("1111"))
                .addEdge(PARIS, BRUSSELS, RegionalTrain.trainNumber("2222"))
                .addEdge(LONDON, PARIS, Eurostar.trainNumber("3333"))
                .addEdge(LONDON, BRUSSELS, Eurostar.trainNumber("4444"))
                .addNode(REYKJAVIK)
                .build();````
        
        Builder instances can be reused; it is safe to call .build multiple times to build
        multiple networks in series. Each new network contains all the elements of the ones created
        before it.

        Since
        - 28.0
        """

        def addNode(self, node: "N") -> "ImmutableNetwork.Builder"["N", "E"]:
            """
            Adds `node` if it is not already present.
            
            **Nodes must be unique**, just as `Map` keys must be. They must also be non-null.

            Returns
            - this `Builder` object
            """
            ...


        def addEdge(self, nodeU: "N", nodeV: "N", edge: "E") -> "ImmutableNetwork.Builder"["N", "E"]:
            """
            Adds `edge` connecting `nodeU` to `nodeV`.
            
            If the network is directed, `edge` will be directed in this network; otherwise, it
            will be undirected.
            
            **`edge` must be unique to this network**, just as a `Map` key must be. It
            must also be non-null.
            
            If `nodeU` and `nodeV` are not already present in this network, this method
            will silently .addNode(Object) add `nodeU` and `nodeV` to the network.
            
            If `edge` already connects `nodeU` to `nodeV` (in the specified order if
            this network .isDirected(), else in any order), then this method will have no effect.

            Returns
            - this `Builder` object

            Raises
            - IllegalArgumentException: if `edge` already exists in the network and does not
                connect `nodeU` to `nodeV`
            - IllegalArgumentException: if the introduction of the edge would violate .allowsParallelEdges() or .allowsSelfLoops()
            """
            ...


        def addEdge(self, endpoints: "EndpointPair"["N"], edge: "E") -> "ImmutableNetwork.Builder"["N", "E"]:
            """
            Adds `edge` connecting `endpoints`. In an undirected network, `edge` will
            also connect `nodeV` to `nodeU`.
            
            If this network is directed, `edge` will be directed in this network; if it is
            undirected, `edge` will be undirected in this network.
            
            If this network is directed, `endpoints` must be ordered.
            
            **`edge` must be unique to this network**, just as a `Map` key must be. It
            must also be non-null.
            
            If either or both endpoints are not already present in this network, this method will
            silently .addNode(Object) add each missing endpoint to the network.
            
            If `edge` already connects an endpoint pair equal to `endpoints`, then this
            method will have no effect.

            Returns
            - this `Builder` object

            Raises
            - IllegalArgumentException: if `edge` already exists in the network and connects
                some other endpoint pair that is not equal to `endpoints`
            - IllegalArgumentException: if the introduction of the edge would violate .allowsParallelEdges() or .allowsSelfLoops()
            - IllegalArgumentException: if the endpoints are unordered and the network is directed
            """
            ...


        def build(self) -> "ImmutableNetwork"["N", "E"]:
            """
            Returns a newly-created `ImmutableNetwork` based on the contents of this `Builder`.
            """
            ...



"""
Python module generated from Java source file java.lang.reflect.Constructor

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.reflect import *
from java.util import StringJoiner
from jdk.internal.access import SharedSecrets
from jdk.internal.reflect import CallerSensitive
from jdk.internal.reflect import ConstructorAccessor
from jdk.internal.reflect import Reflection
from jdk.internal.vm.annotation import ForceInline
from sun.reflect.annotation import TypeAnnotation
from sun.reflect.annotation import TypeAnnotationParser
from sun.reflect.generics.factory import CoreReflectionFactory
from sun.reflect.generics.factory import GenericsFactory
from sun.reflect.generics.repository import ConstructorRepository
from sun.reflect.generics.scope import ConstructorScope
from typing import Any, Callable, Iterable, Tuple


class Constructor(Executable):
    """
    `Constructor` provides information about, and access to, a single
    constructor for a class.
    
    `Constructor` permits widening conversions to occur when matching the
    actual parameters to newInstance() with the underlying
    constructor's formal parameters, but throws an
    `IllegalArgumentException` if a narrowing conversion would occur.
    
    Type `<T>`: the class in which the constructor is declared

    Author(s)
    - Nakul Saraiya

    See
    - java.lang.Class.getDeclaredConstructors()

    Since
    - 1.1
    """

    def setAccessible(self, flag: bool) -> None:
        """
        
        
         A `SecurityException` is also thrown if this object is a
        `Constructor` object for the class `Class` and `flag`
        is True. 

        Arguments
        - flag: 

        Raises
        - InaccessibleObjectException: 
        - SecurityException: if the request is denied by the security manager
                or this is a constructor for `java.lang.Class`
        """
        ...


    def getDeclaringClass(self) -> type["T"]:
        """
        Returns the `Class` object representing the class that
        declares the constructor represented by this object.
        """
        ...


    def getName(self) -> str:
        """
        Returns the name of this constructor, as a string.  This is
        the binary name of the constructor's declaring class.
        """
        ...


    def getModifiers(self) -> int:
        """
        Unknown Tags
        - 8.8.3 Constructor Modifiers
        """
        ...


    def getTypeParameters(self) -> list["TypeVariable"["Constructor"["T"]]]:
        """
        Raises
        - GenericSignatureFormatError: 

        Since
        - 1.5
        """
        ...


    def getParameterTypes(self) -> list[type[Any]]:
        """

        """
        ...


    def getParameterCount(self) -> int:
        """
        Since
        - 1.8
        """
        ...


    def getGenericParameterTypes(self) -> list["Type"]:
        """
        Raises
        - GenericSignatureFormatError: 
        - TypeNotPresentException: 
        - MalformedParameterizedTypeException: 

        Since
        - 1.5
        """
        ...


    def getExceptionTypes(self) -> list[type[Any]]:
        """

        """
        ...


    def getGenericExceptionTypes(self) -> list["Type"]:
        """
        Raises
        - GenericSignatureFormatError: 
        - TypeNotPresentException: 
        - MalformedParameterizedTypeException: 

        Since
        - 1.5
        """
        ...


    def equals(self, obj: "Object") -> bool:
        """
        Compares this `Constructor` against the specified object.
        Returns True if the objects are the same.  Two `Constructor` objects are
        the same if they were declared by the same class and have the
        same formal parameter types.
        """
        ...


    def hashCode(self) -> int:
        """
        Returns a hashcode for this `Constructor`. The hashcode is
        the same as the hashcode for the underlying constructor's
        declaring class name.
        """
        ...


    def toString(self) -> str:
        """
        Returns a string describing this `Constructor`.  The string is
        formatted as the constructor access modifiers, if any,
        followed by the fully-qualified name of the declaring class,
        followed by a parenthesized, comma-separated list of the
        constructor's formal parameter types.  For example:
        ````public java.util.HashMap(int,float)````
        
        If the constructor is declared to throw exceptions, the
        parameter list is followed by a space, followed by the word
        "`throws`" followed by a comma-separated list of the
        thrown exception types.
        
        The only possible modifiers for constructors are the access
        modifiers `public`, `protected` or
        `private`.  Only one of these may appear, or none if the
        constructor has default (package) access.

        Returns
        - a string describing this `Constructor`

        Unknown Tags
        - 8.8.3 Constructor Modifiers
        - 8.9.2 Enum Body Declarations
        """
        ...


    def toGenericString(self) -> str:
        """
        Returns a string describing this `Constructor`,
        including type parameters.  The string is formatted as the
        constructor access modifiers, if any, followed by an
        angle-bracketed comma separated list of the constructor's type
        parameters, if any, including  informative bounds of the
        type parameters, if any, followed by the fully-qualified name of the
        declaring class, followed by a parenthesized, comma-separated
        list of the constructor's generic formal parameter types.
        
        If this constructor was declared to take a variable number of
        arguments, instead of denoting the last parameter as
        "`*Type*[]`", it is denoted as
        "`*Type*...`".
        
        A space is used to separate access modifiers from one another
        and from the type parameters or class name.  If there are no
        type parameters, the type parameter list is elided; if the type
        parameter list is present, a space separates the list from the
        class name.  If the constructor is declared to throw
        exceptions, the parameter list is followed by a space, followed
        by the word "`throws`" followed by a
        comma-separated list of the generic thrown exception types.
        
        The only possible modifiers for constructors are the access
        modifiers `public`, `protected` or
        `private`.  Only one of these may appear, or none if the
        constructor has default (package) access.

        Returns
        - a string describing this `Constructor`,
        include type parameters

        Since
        - 1.5

        Unknown Tags
        - 8.8.3 Constructor Modifiers
        - 8.9.2 Enum Body Declarations
        """
        ...


    def newInstance(self, *initargs: Tuple["Object", ...]) -> "T":
        """
        Uses the constructor represented by this `Constructor` object to
        create and initialize a new instance of the constructor's
        declaring class, with the specified initialization parameters.
        Individual parameters are automatically unwrapped to match
        primitive formal parameters, and both primitive and reference
        parameters are subject to method invocation conversions as necessary.
        
        If the number of formal parameters required by the underlying constructor
        is 0, the supplied `initargs` array may be of length 0 or null.
        
        If the constructor's declaring class is an inner class in a
        non-static context, the first argument to the constructor needs
        to be the enclosing instance; see section 15.9.3 of
        <cite>The Java Language Specification</cite>.
        
        If the required access and argument checks succeed and the
        instantiation will proceed, the constructor's declaring class
        is initialized if it has not already been initialized.
        
        If the constructor completes normally, returns the newly
        created and initialized instance.

        Arguments
        - initargs: array of objects to be passed as arguments to
        the constructor call; values of primitive types are wrapped in
        a wrapper object of the appropriate type (e.g. a `float`
        in a java.lang.Float Float)

        Returns
        - a new object created by calling the constructor
        this object represents

        Raises
        - IllegalAccessException: if this `Constructor` object
                     is enforcing Java language access control and the underlying
                     constructor is inaccessible.
        - IllegalArgumentException: if the number of actual
                     and formal parameters differ; if an unwrapping
                     conversion for primitive arguments fails; or if,
                     after possible unwrapping, a parameter value
                     cannot be converted to the corresponding formal
                     parameter type by a method invocation conversion; if
                     this constructor pertains to an enum class.
        - InstantiationException: if the class that declares the
                     underlying constructor represents an abstract class.
        - InvocationTargetException: if the underlying constructor
                     throws an exception.
        - ExceptionInInitializerError: if the initialization provoked
                     by this method fails.
        """
        ...


    def isVarArgs(self) -> bool:
        """
        Since
        - 1.5

        Unknown Tags
        - 8.4.1 Formal Parameters
        """
        ...


    def isSynthetic(self) -> bool:
        """
        See
        - <a
        href="/java.base/java/lang/reflect/package-summary.html.LanguageJvmModel">Java
        programming language and JVM modeling in core reflection</a>

        Since
        - 1.5

        Unknown Tags
        - 13.1 The Form of a Binary
        - 4.6 Methods
        """
        ...


    def getAnnotation(self, annotationClass: type["T"]) -> "T":
        """
        Raises
        - NullPointerException: 

        Since
        - 1.5
        """
        ...


    def getDeclaredAnnotations(self) -> list["Annotation"]:
        """
        Since
        - 1.5
        """
        ...


    def getParameterAnnotations(self) -> list[list["Annotation"]]:
        """
        Since
        - 1.5
        """
        ...


    def getAnnotatedReturnType(self) -> "AnnotatedType":
        """
        Since
        - 1.8
        """
        ...


    def getAnnotatedReceiverType(self) -> "AnnotatedType":
        """
        Since
        - 1.8
        """
        ...



"""
Python module generated from Java source file com.google.gson.JsonParseException

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from typing import Any, Callable, Iterable, Tuple


class JsonParseException(RuntimeException):
    """
    This exception is raised if there is a serious issue that occurs during parsing of a Json string.
    One of the main usages for this class is for the Gson infrastructure. If the incoming Json is
    bad/malicious, an instance of this exception is raised.
    
    This exception is a RuntimeException because it is exposed to the client. Using a
    RuntimeException avoids bad coding practices on the client side where they catch the
    exception and do nothing. It is often the case that you want to blow up if there is a parsing
    error (i.e. often clients do not know how to recover from a JsonParseException.

    Author(s)
    - Joel Leitch
    """

    def __init__(self, msg: str):
        """
        Creates exception with the specified message. If you are wrapping another exception, consider
        using .JsonParseException(String, Throwable) instead.

        Arguments
        - msg: error message describing a possible cause of this exception.
        """
        ...


    def __init__(self, msg: str, cause: "Throwable"):
        """
        Creates exception with the specified message and cause.

        Arguments
        - msg: error message describing what happened.
        - cause: root exception that caused this exception to be thrown.
        """
        ...


    def __init__(self, cause: "Throwable"):
        """
        Creates exception with the specified cause. Consider using .JsonParseException(String,
        Throwable) instead if you can describe what happened.

        Arguments
        - cause: root exception that caused this exception to be thrown.
        """
        ...



"""
Python module generated from Java source file org.bukkit.FluidCollisionMode

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class FluidCollisionMode(Enum):
    """
    Determines the collision behavior when fluids get hit during ray tracing.
    """

    NEVER = 0
    """
    Ignore fluids.
    """
    SOURCE_ONLY = 1
    """
    Only collide with source fluid blocks.
    """
    ALWAYS = 2
    """
    Collide with all fluids.
    """



"""
Python module generated from Java source file org.bukkit.util.permissions.DefaultPermissions

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Bukkit
from org.bukkit.permissions import Permission
from org.bukkit.permissions import PermissionDefault
from org.bukkit.util.permissions import *
from typing import Any, Callable, Iterable, Tuple


class DefaultPermissions:

    @staticmethod
    def registerPermission(perm: "Permission") -> "Permission":
        ...


    @staticmethod
    def registerPermission(perm: "Permission", withLegacy: bool) -> "Permission":
        ...


    @staticmethod
    def registerPermission(perm: "Permission", parent: "Permission") -> "Permission":
        ...


    @staticmethod
    def registerPermission(name: str, desc: str) -> "Permission":
        ...


    @staticmethod
    def registerPermission(name: str, desc: str, parent: "Permission") -> "Permission":
        ...


    @staticmethod
    def registerPermission(name: str, desc: str, def: "PermissionDefault") -> "Permission":
        ...


    @staticmethod
    def registerPermission(name: str, desc: str, def: "PermissionDefault", parent: "Permission") -> "Permission":
        ...


    @staticmethod
    def registerPermission(name: str, desc: str, def: "PermissionDefault", children: dict[str, "Boolean"]) -> "Permission":
        ...


    @staticmethod
    def registerPermission(name: str, desc: str, def: "PermissionDefault", children: dict[str, "Boolean"], parent: "Permission") -> "Permission":
        ...


    @staticmethod
    def registerCorePermissions() -> None:
        ...



"""
Python module generated from Java source file org.bukkit.inventory.CraftingInventory

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.inventory import *
from typing import Any, Callable, Iterable, Tuple


class CraftingInventory(Inventory):
    """
    Interface to the crafting inventories
    """

    def getResult(self) -> "ItemStack":
        """
        Check what item is in the result slot of this crafting inventory.

        Returns
        - The result item.
        """
        ...


    def getMatrix(self) -> list["ItemStack"]:
        """
        Get the contents of the crafting matrix.

        Returns
        - The contents. Individual entries may be null.
        """
        ...


    def setResult(self, newResult: "ItemStack") -> None:
        """
        Set the item in the result slot of the crafting inventory.

        Arguments
        - newResult: The new result item.
        """
        ...


    def setMatrix(self, contents: list["ItemStack"]) -> None:
        """
        Replace the contents of the crafting matrix

        Arguments
        - contents: The new contents. Individual entries may be null.

        Raises
        - IllegalArgumentException: if the length of contents is greater
            than the size of the crafting matrix.
        """
        ...


    def getRecipe(self) -> "Recipe":
        """
        Get the current recipe formed on the crafting inventory, if any.

        Returns
        - The recipe, or null if the current contents don't match any
            recipe.
        """
        ...



"""
Python module generated from Java source file org.joml.Interpolationd

Java source file obtained from artifact joml version 1.10.8

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.joml import *
from typing import Any, Callable, Iterable, Tuple


class Interpolationd:
    """
    Contains various interpolation functions.

    Author(s)
    - Kai Burjack
    """

    @staticmethod
    def interpolateTriangle(v0X: float, v0Y: float, f0: float, v1X: float, v1Y: float, f1: float, v2X: float, v2Y: float, f2: float, x: float, y: float) -> float:
        """
        Bilinearly interpolate the single scalar value *f* over the given triangle.
        
        Reference: <a href="https://en.wikipedia.org/wiki/Barycentric_coordinate_system">https://en.wikipedia.org/</a>

        Arguments
        - v0X: the x coordinate of the first triangle vertex
        - v0Y: the y coordinate of the first triangle vertex
        - f0: the value of *f* at the first vertex
        - v1X: the x coordinate of the second triangle vertex
        - v1Y: the y coordinate of the second triangle vertex
        - f1: the value of *f* at the second vertex
        - v2X: the x coordinate of the third triangle vertex
        - v2Y: the y coordinate of the third triangle vertex
        - f2: the value of *f* at the third vertex
        - x: the x coordinate of the point to interpolate *f* at
        - y: the y coordinate of the point to interpolate *f* at

        Returns
        - the interpolated value of *f*
        """
        ...


    @staticmethod
    def interpolateTriangle(v0X: float, v0Y: float, f0X: float, f0Y: float, v1X: float, v1Y: float, f1X: float, f1Y: float, v2X: float, v2Y: float, f2X: float, f2Y: float, x: float, y: float, dest: "Vector2d") -> "Vector2d":
        """
        Bilinearly interpolate the two-dimensional vector *f* over the given triangle and store the result in `dest`.
        
        Reference: <a href="https://en.wikipedia.org/wiki/Barycentric_coordinate_system">https://en.wikipedia.org/</a>

        Arguments
        - v0X: the x coordinate of the first triangle vertex
        - v0Y: the y coordinate of the first triangle vertex
        - f0X: the x component of the value of *f* at the first vertex
        - f0Y: the y component of the value of *f* at the first vertex
        - v1X: the x coordinate of the second triangle vertex
        - v1Y: the y coordinate of the second triangle vertex
        - f1X: the x component of the value of *f* at the second vertex
        - f1Y: the y component of the value of *f* at the second vertex
        - v2X: the x coordinate of the third triangle vertex
        - v2Y: the y coordinate of the third triangle vertex
        - f2X: the x component of the value of *f* at the third vertex
        - f2Y: the y component of the value of *f* at the third vertex
        - x: the x coordinate of the point to interpolate *f* at
        - y: the y coordinate of the point to interpolate *f* at
        - dest: will hold the interpolation result

        Returns
        - dest
        """
        ...


    @staticmethod
    def dFdxLinear(v0X: float, v0Y: float, f0X: float, f0Y: float, v1X: float, v1Y: float, f1X: float, f1Y: float, v2X: float, v2Y: float, f2X: float, f2Y: float, dest: "Vector2d") -> "Vector2d":
        """
        Compute the first-order derivative of a linear two-dimensional function *f* with respect to X
        and store the result in `dest`.
        
        This method computes the constant rate of change for *f* given the three values of *f*
        at the specified three inputs `(v0X, v0Y)`, `(v1X, v1Y)` and `(v2X, v2Y)`.

        Arguments
        - v0X: the x coordinate of the first triangle vertex
        - v0Y: the y coordinate of the first triangle vertex
        - f0X: the x component of the value of *f* at the first vertex
        - f0Y: the y component of the value of *f* at the first vertex
        - v1X: the x coordinate of the second triangle vertex
        - v1Y: the y coordinate of the second triangle vertex
        - f1X: the x component of the value of *f* at the second vertex
        - f1Y: the y component of the value of *f* at the second vertex
        - v2X: the x coordinate of the third triangle vertex
        - v2Y: the y coordinate of the third triangle vertex
        - f2X: the x component of the value of *f* at the third vertex
        - f2Y: the y component of the value of *f* at the third vertex
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    @staticmethod
    def dFdyLinear(v0X: float, v0Y: float, f0X: float, f0Y: float, v1X: float, v1Y: float, f1X: float, f1Y: float, v2X: float, v2Y: float, f2X: float, f2Y: float, dest: "Vector2d") -> "Vector2d":
        """
        Compute the first-order derivative of a linear two-dimensional function *f* with respect to Y
        and store the result in `dest`.
        
        This method computes the constant rate of change for *f* given the three values of *f*
        at the specified three inputs `(v0X, v0Y)`, `(v1X, v1Y)` and `(v2X, v2Y)`.

        Arguments
        - v0X: the x coordinate of the first triangle vertex
        - v0Y: the y coordinate of the first triangle vertex
        - f0X: the x component of the value of *f* at the first vertex
        - f0Y: the y component of the value of *f* at the first vertex
        - v1X: the x coordinate of the second triangle vertex
        - v1Y: the y coordinate of the second triangle vertex
        - f1X: the x component of the value of *f* at the second vertex
        - f1Y: the y component of the value of *f* at the second vertex
        - v2X: the x coordinate of the third triangle vertex
        - v2Y: the y coordinate of the third triangle vertex
        - f2X: the x component of the value of *f* at the third vertex
        - f2Y: the y component of the value of *f* at the third vertex
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    @staticmethod
    def interpolateTriangle(v0X: float, v0Y: float, f0X: float, f0Y: float, f0Z: float, v1X: float, v1Y: float, f1X: float, f1Y: float, f1Z: float, v2X: float, v2Y: float, f2X: float, f2Y: float, f2Z: float, x: float, y: float, dest: "Vector3d") -> "Vector3d":
        """
        Bilinearly interpolate the three-dimensional vector *f* over the given triangle and store the result in `dest`.
        
        Reference: <a href="https://en.wikipedia.org/wiki/Barycentric_coordinate_system">https://en.wikipedia.org/</a>

        Arguments
        - v0X: the x coordinate of the first triangle vertex
        - v0Y: the y coordinate of the first triangle vertex
        - f0X: the x component of the value of *f* at the first vertex
        - f0Y: the y component of the value of *f* at the first vertex
        - f0Z: the z component of the value of *f* at the first vertex
        - v1X: the x coordinate of the second triangle vertex
        - v1Y: the y coordinate of the second triangle vertex
        - f1X: the x component of the value of *f* at the second vertex
        - f1Y: the y component of the value of *f* at the second vertex
        - f1Z: the z component of the value of *f* at the second vertex
        - v2X: the x coordinate of the third triangle vertex
        - v2Y: the y coordinate of the third triangle vertex
        - f2X: the x component of the value of *f* at the third vertex
        - f2Y: the y component of the value of *f* at the third vertex
        - f2Z: the z component of the value of *f* at the third vertex
        - x: the x coordinate of the point to interpolate *f* at
        - y: the y coordinate of the point to interpolate *f* at
        - dest: will hold the interpolation result

        Returns
        - dest
        """
        ...


    @staticmethod
    def interpolationFactorsTriangle(v0X: float, v0Y: float, v1X: float, v1Y: float, v2X: float, v2Y: float, x: float, y: float, dest: "Vector3d") -> "Vector3d":
        """
        Compute the interpolation factors `(t0, t1, t2)` in order to interpolate an arbitrary value over a given 
        triangle at the given point `(x, y)`.
        
        This method takes in the 2D vertex positions of the three vertices of a triangle and stores in `dest` the 
        factors `(t0, t1, t2)` in the equation `v' = v0 * t0 + v1 * t1 + v2 * t2` where `(v0, v1, v2)` are
        arbitrary (scalar or vector) values associated with the respective vertices of the triangle. The computed value `v'`
        is the interpolated value at the given position `(x, y)`.

        Arguments
        - v0X: the x coordinate of the first triangle vertex
        - v0Y: the y coordinate of the first triangle vertex
        - v1X: the x coordinate of the second triangle vertex
        - v1Y: the y coordinate of the second triangle vertex
        - v2X: the x coordinate of the third triangle vertex
        - v2Y: the y coordinate of the third triangle vertex
        - x: the x coordinate of the point to interpolate at
        - y: the y coordinate of the point to interpolate at
        - dest: will hold the interpolation factors `(t0, t1, t2)`

        Returns
        - dest
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Husk

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Husk(Zombie):
    """
    Represents a Husk - variant of Zombie.
    """

    def isConverting(self) -> bool:
        """
        Get if this entity is in the process of converting to a Zombie as a
        result of being underwater.

        Returns
        - conversion status
        """
        ...


    def getConversionTime(self) -> int:
        """
        Gets the amount of ticks until this entity will be converted to a Zombie
        as a result of being underwater.
        
        When this reaches 0, the entity will be converted.

        Returns
        - conversion time

        Raises
        - IllegalStateException: if .isConverting() is False.
        """
        ...


    def setConversionTime(self, time: int) -> None:
        """
        Sets the amount of ticks until this entity will be converted to a Zombie
        as a result of being underwater.
        
        When this reaches 0, the entity will be converted. A value of less than 0
        will stop the current conversion process without converting the current
        entity.

        Arguments
        - time: new conversion time
        """
        ...



"""
Python module generated from Java source file org.bukkit.plugin.EventExecutor

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.event import Event
from org.bukkit.event import EventException
from org.bukkit.event import Listener
from org.bukkit.plugin import *
from typing import Any, Callable, Iterable, Tuple


class EventExecutor:
    """
    Interface which defines the class for event call backs to plugins
    """

    def execute(self, listener: "Listener", event: "Event") -> None:
        ...



"""
Python module generated from Java source file org.bukkit.entity.SkeletonHorse

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class SkeletonHorse(AbstractHorse):
    """
    Represents a SkeletonHorse - variant of AbstractHorse.
    """

    def isTrapped(self) -> bool:
        """
        Returns whether this skeleton horse is trapped.
        
        When a horse is trapped and a player comes within 10 blocks of a trapped
        horse, lightning will strike the horse. When struck, the skeleton trap
        will activate, turning the horse into a skeleton horseman as well as
        spawning three additional horsemen nearby.

        Returns
        - True if trapped
        """
        ...


    def setTrapped(self, trapped: bool) -> None:
        """
        Sets if this skeleton horse is trapped.

        Arguments
        - trapped: new trapped state
        """
        ...


    def getTrapTime(self) -> int:
        """
        Returns the horse's current trap time in ticks.
        
        Trap time is incremented every tick when .isTrapped() is True.
        The horse automatically despawns when it reaches 18000 ticks.

        Returns
        - current trap time
        """
        ...


    def setTrapTime(self, trapTime: int) -> None:
        """
        Sets the trap time for the horse.
        
        Values greater than 18000 will cause the horse to despawn on the next
        tick.

        Arguments
        - trapTime: new trap time
        """
        ...



"""
Python module generated from Java source file com.google.gson.Gson

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from com.google.gson.annotations import JsonAdapter
from com.google.gson.internal import ConstructorConstructor
from com.google.gson.internal import Excluder
from com.google.gson.internal import GsonBuildConfig
from com.google.gson.internal import LazilyParsedNumber
from com.google.gson.internal import Primitives
from com.google.gson.internal import Streams
from com.google.gson.internal.bind import ArrayTypeAdapter
from com.google.gson.internal.bind import CollectionTypeAdapterFactory
from com.google.gson.internal.bind import DefaultDateTypeAdapter
from com.google.gson.internal.bind import JsonAdapterAnnotationTypeAdapterFactory
from com.google.gson.internal.bind import JsonTreeReader
from com.google.gson.internal.bind import JsonTreeWriter
from com.google.gson.internal.bind import MapTypeAdapterFactory
from com.google.gson.internal.bind import NumberTypeAdapter
from com.google.gson.internal.bind import ObjectTypeAdapter
from com.google.gson.internal.bind import ReflectiveTypeAdapterFactory
from com.google.gson.internal.bind import SerializationDelegatingTypeAdapter
from com.google.gson.internal.bind import TypeAdapters
from com.google.gson.internal.sql import SqlTypesSupport
from com.google.gson.reflect import TypeToken
from com.google.gson.stream import JsonReader
from com.google.gson.stream import JsonToken
from com.google.gson.stream import JsonWriter
from com.google.gson.stream import MalformedJsonException
from java.io import EOFException
from java.io import IOException
from java.io import Reader
from java.io import StringReader
from java.io import StringWriter
from java.io import Writer
from java.lang.reflect import Type
from java.math import BigDecimal
from java.math import BigInteger
from java.text import DateFormat
from java.util import Collections
from java.util import Objects
from java.util.concurrent import ConcurrentHashMap
from java.util.concurrent import ConcurrentMap
from java.util.concurrent.atomic import AtomicLong
from java.util.concurrent.atomic import AtomicLongArray
from typing import Any, Callable, Iterable, Tuple


class Gson:
    """
    This is the main class for using Gson. Gson is typically used by first constructing a Gson
    instance and then invoking .toJson(Object) or .fromJson(String, Class) methods on
    it. Gson instances are Thread-safe so you can reuse them freely across multiple threads.
    
    You can create a Gson instance by invoking `new Gson()` if the default configuration is
    all you need. You can also use GsonBuilder to build a Gson instance with various
    configuration options such as versioning support, pretty printing, custom newline, custom indent,
    custom JsonSerializers, JsonDeserializers, and InstanceCreators.
    
    Here is an example of how Gson is used for a simple Class:
    
    ```
    Gson gson = new Gson(); // Or use new GsonBuilder().create();
    MyType target = new MyType();
    String json = gson.toJson(target); // serializes target to JSON
    MyType target2 = gson.fromJson(json, MyType.class); // deserializes json into target2
    ```
    
    If the type of the object that you are converting is a `ParameterizedType` (i.e. has at
    least one type argument, for example `List<MyType>`) then for deserialization you must use
    a `fromJson` method with Type or TypeToken parameter to specify the
    parameterized type. For serialization specifying a `Type` or `TypeToken` is optional,
    otherwise Gson will use the runtime type of the object. TypeToken is a class provided by
    Gson which helps creating parameterized types. Here is an example showing how this can be done:
    
    ```
    TypeToken&lt;List&lt;MyType&gt;&gt; listType = new TypeToken&lt;List&lt;MyType&gt;&gt;() {};
    List&lt;MyType&gt; target = new LinkedList&lt;MyType&gt;();
    target.add(new MyType(1, "abc"));
    
    Gson gson = new Gson();
    // For serialization you normally do not have to specify the type, Gson will use
    // the runtime type of the objects, however you can also specify it explicitly
    String json = gson.toJson(target, listType.getType());
    
    // But for deserialization you have to specify the type
    List&lt;MyType&gt; target2 = gson.fromJson(json, listType);
    ```
    
    See the <a href="https://github.com/google/gson/blob/main/UserGuide.md">Gson User Guide</a>
    for a more complete set of examples.
    
    <h2 id="default-lenient">JSON Strictness handling</h2>
    
    For legacy reasons most of the `Gson` methods allow JSON data which does not comply with
    the JSON specification when no explicit Strictness strictness is set (the default).
    To specify the strictness of a `Gson` instance, you should set it through GsonBuilder.setStrictness(Strictness).
    
    For older Gson versions, which don't have the strictness mode API, the following workarounds
    can be used:
    
    <h3>Serialization</h3>
    
    <ol>
      - Use .getAdapter(Class) to obtain the adapter for the type to be serialized
      - When using an existing `JsonWriter`, manually apply the writer settings of this
          `Gson` instance listed by .newJsonWriter(Writer).
          Otherwise, when not using an existing `JsonWriter`, use .newJsonWriter(Writer) to construct one.
      - Call TypeAdapter.write(JsonWriter, Object)
    </ol>
    
    <h3>Deserialization</h3>
    
    <ol>
      - Use .getAdapter(Class) to obtain the adapter for the type to be deserialized
      - When using an existing `JsonReader`, manually apply the reader settings of this
          `Gson` instance listed by .newJsonReader(Reader).
          Otherwise, when not using an existing `JsonReader`, use .newJsonReader(Reader) to construct one.
      - Call TypeAdapter.read(JsonReader)
      - Call JsonReader.peek() and verify that the result is JsonToken.END_DOCUMENT
          to make sure there is no trailing data
    </ol>
    
    Note that the `JsonReader` created this way is only 'legacy strict', it mostly adheres to
    the JSON specification but allows small deviations. See JsonReader.setStrictness(Strictness) for details.

    Author(s)
    - Jesse Wilson

    See
    - TypeToken
    """

    def __init__(self):
        """
        Constructs a Gson object with default configuration. The default configuration has the
        following settings:
        
        
          - The JSON generated by `toJson` methods is in compact representation. This means
              that all the unneeded white-space is removed. You can change this behavior with GsonBuilder.setPrettyPrinting().
          - When the JSON generated contains more than one line, the kind of newline and indent to
              use can be configured with GsonBuilder.setFormattingStyle(FormattingStyle).
          - The generated JSON omits all the fields that are null. Note that nulls in arrays are kept
              as is since an array is an ordered list. Moreover, if a field is not null, but its
              generated JSON is empty, the field is kept. You can configure Gson to serialize null
              values by setting GsonBuilder.serializeNulls().
          - Gson provides default serialization and deserialization for Enums, Map, java.net.URL, java.net.URI, java.util.Locale, java.util.Date,
              java.math.BigDecimal, and java.math.BigInteger classes. If you would
              prefer to change the default representation, you can do so by registering a type adapter
              through GsonBuilder.registerTypeAdapter(Type, Object).
          - The default Date format is same as java.text.DateFormat.DEFAULT. This format
              ignores the millisecond portion of the date during serialization. You can change this by
              invoking GsonBuilder.setDateFormat(int, int) or GsonBuilder.setDateFormat(String).
          - By default, Gson ignores the com.google.gson.annotations.Expose annotation. You
              can enable Gson to serialize/deserialize only those fields marked with this annotation
              through GsonBuilder.excludeFieldsWithoutExposeAnnotation().
          - By default, Gson ignores the com.google.gson.annotations.Since annotation. You
              can enable Gson to use this annotation through GsonBuilder.setVersion(double).
          - The default field naming policy for the output JSON is same as in Java. So, a Java class
              field `versionNumber` will be output as `"versionNumber"` in JSON. The same
              rules are applied for mapping incoming JSON to the Java classes. You can change this
              policy through GsonBuilder.setFieldNamingPolicy(FieldNamingPolicy).
          - By default, Gson excludes `transient` or `static` fields from consideration
              for serialization and deserialization. You can change this behavior through GsonBuilder.excludeFieldsWithModifiers(int...).
          - No explicit strictness is set. You can change this by calling GsonBuilder.setStrictness(Strictness).
        """
        ...


    def newBuilder(self) -> "GsonBuilder":
        """
        Returns a new GsonBuilder containing all custom factories and configuration used by the current
        instance.

        Returns
        - a GsonBuilder instance.

        Since
        - 2.8.3
        """
        ...


    def excluder(self) -> "Excluder":
        """
        Deprecated
        - This method by accident exposes an internal Gson class; it might be removed in a
            future version.
        """
        ...


    def fieldNamingStrategy(self) -> "FieldNamingStrategy":
        """
        Returns the field naming strategy used by this Gson instance.

        See
        - GsonBuilder.setFieldNamingStrategy(FieldNamingStrategy)
        """
        ...


    def serializeNulls(self) -> bool:
        """
        Returns whether this Gson instance is serializing JSON object properties with `null`
        values, or just omits them.

        See
        - GsonBuilder.serializeNulls()
        """
        ...


    def htmlSafe(self) -> bool:
        """
        Returns whether this Gson instance produces JSON output which is HTML-safe, that means all HTML
        characters are escaped.

        See
        - GsonBuilder.disableHtmlEscaping()
        """
        ...


    def getAdapter(self, type: "TypeToken"["T"]) -> "TypeAdapter"["T"]:
        """
        Returns the type adapter for `type`.
        
        When calling this method concurrently from multiple threads and requesting an adapter for
        the same type this method may return different `TypeAdapter` instances. However, that
        should normally not be an issue because `TypeAdapter` implementations are supposed to be
        stateless.

        Raises
        - IllegalArgumentException: if this Gson instance cannot serialize and deserialize `type`.
        """
        ...


    def getAdapter(self, type: type["T"]) -> "TypeAdapter"["T"]:
        """
        Returns the type adapter for `type`.

        Raises
        - IllegalArgumentException: if this Gson instance cannot serialize and deserialize `type`.
        """
        ...


    def getDelegateAdapter(self, skipPast: "TypeAdapterFactory", type: "TypeToken"["T"]) -> "TypeAdapter"["T"]:
        """
        This method is used to get an alternate type adapter for the specified type. This is used to
        access a type adapter that is overridden by a TypeAdapterFactory that you may have
        registered. This feature is typically used when you want to register a type adapter that does a
        little bit of work but then delegates further processing to the Gson default type adapter. Here
        is an example:
        
        Let's say we want to write a type adapter that counts the number of objects being read from
        or written to JSON. We can achieve this by writing a type adapter factory that uses the `getDelegateAdapter` method:
        
        ````class StatsTypeAdapterFactory implements TypeAdapterFactory {
          public int numReads = 0;
          public int numWrites = 0;
          public <T> TypeAdapter<T> create(Gson gson, TypeToken<T> type) {
            final TypeAdapter<T> delegate = gson.getDelegateAdapter(this, type);
            return new TypeAdapter<T>() {
              public void write(JsonWriter out, T value) throws IOException {
                ++numWrites;
                delegate.write(out, value);`
              public T read(JsonReader in) throws IOException {
                ++numReads;
                return delegate.read(in);
              }
            };
          }
        }
        }```
        
        This factory can now be used like this:
        
        ````StatsTypeAdapterFactory stats = new StatsTypeAdapterFactory();
        Gson gson = new GsonBuilder().registerTypeAdapterFactory(stats).create();
        // Call gson.toJson() and fromJson methods on objects
        System.out.println("Num JSON reads: " + stats.numReads);
        System.out.println("Num JSON writes: " + stats.numWrites);````
        
        Note that this call will skip all factories registered before `skipPast`. In case of
        multiple TypeAdapterFactories registered it is up to the caller of this function to ensure that
        the order of registration does not prevent this method from reaching a factory they would
        expect to reply from this call. Note that since you can not override the type adapter factories
        for some types, see GsonBuilder.registerTypeAdapter(Type, Object), our stats factory
        will not count the number of instances of those types that will be read or written.
        
        If `skipPast` is a factory which has neither been registered on the GsonBuilder nor specified with the JsonAdapter @JsonAdapter annotation on a class,
        then this method behaves as if .getAdapter(TypeToken) had been called. This also means
        that for fields with `@JsonAdapter` annotation this method behaves normally like `getAdapter` (except for corner cases where a custom InstanceCreator is used to create
        an instance of the factory).

        Arguments
        - skipPast: The type adapter factory that needs to be skipped while searching for a
            matching type adapter. In most cases, you should just pass *this* (the type adapter
            factory from where `getDelegateAdapter` method is being invoked).
        - type: Type for which the delegate adapter is being searched for.

        Since
        - 2.2
        """
        ...


    def toJsonTree(self, src: "Object") -> "JsonElement":
        """
        This method serializes the specified object into its equivalent representation as a tree of
        JsonElements. This method should be used when the specified object is not a generic
        type. This method uses Class.getClass() to get the type for the specified object, but
        the `getClass()` loses the generic type information because of the Type Erasure feature
        of Java. Note that this method works fine if any of the object fields are of generic type, just
        the object itself should not be of a generic type. If the object is of generic type, use .toJsonTree(Object, Type) instead.

        Arguments
        - src: the object for which JSON representation is to be created

        Returns
        - JSON representation of `src`.

        See
        - .toJsonTree(Object, Type)

        Since
        - 1.4
        """
        ...


    def toJsonTree(self, src: "Object", typeOfSrc: "Type") -> "JsonElement":
        """
        This method serializes the specified object, including those of generic types, into its
        equivalent representation as a tree of JsonElements. This method must be used if the
        specified object is a generic type. For non-generic objects, use .toJsonTree(Object)
        instead.

        Arguments
        - src: the object for which JSON representation is to be created
        - typeOfSrc: The specific genericized type of src. You can obtain this type by using the
            com.google.gson.reflect.TypeToken class. For example, to get the type for `Collection<Foo>`, you should use:
            ```
        Type typeOfSrc = new TypeToken&lt;Collection&lt;Foo&gt;&gt;(){}.getType();
        ```

        Returns
        - JSON representation of `src`.

        See
        - .toJsonTree(Object)

        Since
        - 1.4
        """
        ...


    def toJson(self, src: "Object") -> str:
        """
        This method serializes the specified object into its equivalent JSON representation. This
        method should be used when the specified object is not a generic type. This method uses Class.getClass() to get the type for the specified object, but the `getClass()` loses
        the generic type information because of the Type Erasure feature of Java. Note that this method
        works fine if any of the object fields are of generic type, just the object itself should not
        be of a generic type. If the object is of generic type, use .toJson(Object, Type)
        instead. If you want to write out the object to a Writer, use .toJson(Object,
        Appendable) instead.

        Arguments
        - src: the object for which JSON representation is to be created

        Returns
        - JSON representation of `src`.

        See
        - .toJson(Object, Type)
        """
        ...


    def toJson(self, src: "Object", typeOfSrc: "Type") -> str:
        """
        This method serializes the specified object, including those of generic types, into its
        equivalent JSON representation. This method must be used if the specified object is a generic
        type. For non-generic objects, use .toJson(Object) instead. If you want to write out
        the object to a Appendable, use .toJson(Object, Type, Appendable) instead.

        Arguments
        - src: the object for which JSON representation is to be created
        - typeOfSrc: The specific genericized type of src. You can obtain this type by using the
            com.google.gson.reflect.TypeToken class. For example, to get the type for `Collection<Foo>`, you should use:
            ```
        Type typeOfSrc = new TypeToken&lt;Collection&lt;Foo&gt;&gt;(){}.getType();
        ```

        Returns
        - JSON representation of `src`.

        See
        - .toJson(Object)
        """
        ...


    def toJson(self, src: "Object", writer: "Appendable") -> None:
        """
        This method serializes the specified object into its equivalent JSON representation and writes
        it to the writer. This method should be used when the specified object is not a generic type.
        This method uses Class.getClass() to get the type for the specified object, but the
        `getClass()` loses the generic type information because of the Type Erasure feature of
        Java. Note that this method works fine if any of the object fields are of generic type, just
        the object itself should not be of a generic type. If the object is of generic type, use .toJson(Object, Type, Appendable) instead.

        Arguments
        - src: the object for which JSON representation is to be created
        - writer: Writer to which the JSON representation needs to be written

        Raises
        - JsonIOException: if there was a problem writing to the writer

        See
        - .toJson(Object, Type, Appendable)

        Since
        - 1.2
        """
        ...


    def toJson(self, src: "Object", typeOfSrc: "Type", writer: "Appendable") -> None:
        """
        This method serializes the specified object, including those of generic types, into its
        equivalent JSON representation and writes it to the writer. This method must be used if the
        specified object is a generic type. For non-generic objects, use .toJson(Object,
        Appendable) instead.

        Arguments
        - src: the object for which JSON representation is to be created
        - typeOfSrc: The specific genericized type of src. You can obtain this type by using the
            com.google.gson.reflect.TypeToken class. For example, to get the type for `Collection<Foo>`, you should use:
            ```
        Type typeOfSrc = new TypeToken&lt;Collection&lt;Foo&gt;&gt;(){}.getType();
        ```
        - writer: Writer to which the JSON representation of src needs to be written

        Raises
        - JsonIOException: if there was a problem writing to the writer

        See
        - .toJson(Object, Appendable)

        Since
        - 1.2
        """
        ...


    def toJson(self, src: "Object", typeOfSrc: "Type", writer: "JsonWriter") -> None:
        """
        Writes the JSON representation of `src` of type `typeOfSrc` to `writer`.
        
        If the `Gson` instance has an GsonBuilder.setStrictness(Strictness)
        explicit strictness setting, this setting will be used for writing the JSON regardless of the
        JsonWriter.getStrictness() strictness of the provided JsonWriter. For
        legacy reasons, if the `Gson` instance has no explicit strictness setting and the writer
        does not have the strictness Strictness.STRICT, the JSON will be written in Strictness.LENIENT mode.
        Note that in all cases the old strictness setting of the writer will be restored when this
        method returns.
        
        The 'HTML-safe' and 'serialize `null`' settings of this `Gson` instance
        (configured by the GsonBuilder) are applied, and the original settings of the writer
        are restored once this method returns.

        Arguments
        - src: the object for which JSON representation is to be created
        - typeOfSrc: the type of the object to be written
        - writer: Writer to which the JSON representation of src needs to be written

        Raises
        - JsonIOException: if there was a problem writing to the writer
        """
        ...


    def toJson(self, jsonElement: "JsonElement") -> str:
        """
        Converts a tree of JsonElements into its equivalent JSON representation.

        Arguments
        - jsonElement: root of a tree of JsonElements

        Returns
        - JSON String representation of the tree.

        Since
        - 1.4
        """
        ...


    def toJson(self, jsonElement: "JsonElement", writer: "Appendable") -> None:
        """
        Writes out the equivalent JSON for a tree of JsonElements.

        Arguments
        - jsonElement: root of a tree of JsonElements
        - writer: Writer to which the JSON representation needs to be written

        Raises
        - JsonIOException: if there was a problem writing to the writer

        Since
        - 1.4
        """
        ...


    def toJson(self, jsonElement: "JsonElement", writer: "JsonWriter") -> None:
        """
        Writes the JSON for `jsonElement` to `writer`.
        
        If the `Gson` instance has an GsonBuilder.setStrictness(Strictness)
        explicit strictness setting, this setting will be used for writing the JSON regardless of the
        JsonWriter.getStrictness() strictness of the provided JsonWriter. For
        legacy reasons, if the `Gson` instance has no explicit strictness setting and the writer
        does not have the strictness Strictness.STRICT, the JSON will be written in Strictness.LENIENT mode.
        Note that in all cases the old strictness setting of the writer will be restored when this
        method returns.
        
        The 'HTML-safe' and 'serialize `null`' settings of this `Gson` instance
        (configured by the GsonBuilder) are applied, and the original settings of the writer
        are restored once this method returns.

        Arguments
        - jsonElement: the JSON element to be written
        - writer: the JSON writer to which the provided element will be written

        Raises
        - JsonIOException: if there was a problem writing to the writer
        """
        ...


    def newJsonWriter(self, writer: "Writer") -> "JsonWriter":
        """
        Returns a new JSON writer configured for the settings on this Gson instance.
        
        The following settings are considered:
        
        
          - GsonBuilder.disableHtmlEscaping()
          - GsonBuilder.generateNonExecutableJson()
          - GsonBuilder.serializeNulls()
          - GsonBuilder.setStrictness(Strictness). If no GsonBuilder.setStrictness(Strictness) explicit strictness has been set the created
              writer will have a strictness of Strictness.LEGACY_STRICT. Otherwise, the
              strictness of the `Gson` instance will be used for the created writer.
          - GsonBuilder.setPrettyPrinting()
          - GsonBuilder.setFormattingStyle(FormattingStyle)
        """
        ...


    def newJsonReader(self, reader: "Reader") -> "JsonReader":
        """
        Returns a new JSON reader configured for the settings on this Gson instance.
        
        The following settings are considered:
        
        
          - GsonBuilder.setStrictness(Strictness). If no GsonBuilder.setStrictness(Strictness) explicit strictness has been set the created
              reader will have a strictness of Strictness.LEGACY_STRICT. Otherwise, the
              strictness of the `Gson` instance will be used for the created reader.
        """
        ...


    def fromJson(self, json: str, classOfT: type["T"]) -> "T":
        """
        This method deserializes the specified JSON into an object of the specified class. It is not
        suitable to use if the specified class is a generic type since it will not have the generic
        type information because of the Type Erasure feature of Java. Therefore, this method should not
        be used if the desired type is a generic type. Note that this method works fine if any of the
        fields of the specified object are generics, just the object itself should not be a generic
        type. For the cases when the object is of generic type, invoke .fromJson(String,
        TypeToken). If you have the JSON in a Reader instead of a String, use .fromJson(Reader, Class) instead.
        
        An exception is thrown if the JSON string has multiple top-level JSON elements, or if there
        is trailing data. Use .fromJson(JsonReader, Type) if this behavior is not desired.
        
        Type `<T>`: the type of the desired object

        Arguments
        - json: the string from which the object is to be deserialized
        - classOfT: the class of T

        Returns
        - an object of type T from the string. Returns `null` if `json` is `null` or if `json` is empty.

        Raises
        - JsonSyntaxException: if json is not a valid representation for an object of type
            classOfT

        See
        - .fromJson(String, TypeToken)
        """
        ...


    def fromJson(self, json: str, typeOfT: "Type") -> "T":
        """
        This method deserializes the specified JSON into an object of the specified type. This method
        is useful if the specified object is a generic type. For non-generic objects, use .fromJson(String, Class) instead. If you have the JSON in a Reader instead of a
        String, use .fromJson(Reader, Type) instead.
        
        Since `Type` is not parameterized by T, this method is not type-safe and should be
        used carefully. If you are creating the `Type` from a TypeToken, prefer using
        .fromJson(String, TypeToken) instead since its return type is based on the `TypeToken` and is therefore more type-safe.
        
        An exception is thrown if the JSON string has multiple top-level JSON elements, or if there
        is trailing data. Use .fromJson(JsonReader, Type) if this behavior is not desired.
        
        Type `<T>`: the type of the desired object

        Arguments
        - json: the string from which the object is to be deserialized
        - typeOfT: The specific genericized type of src

        Returns
        - an object of type T from the string. Returns `null` if `json` is `null` or if `json` is empty.

        Raises
        - JsonSyntaxException: if json is not a valid representation for an object of type typeOfT

        See
        - .fromJson(String, TypeToken)
        """
        ...


    def fromJson(self, json: str, typeOfT: "TypeToken"["T"]) -> "T":
        """
        This method deserializes the specified JSON into an object of the specified type. This method
        is useful if the specified object is a generic type. For non-generic objects, use .fromJson(String, Class) instead. If you have the JSON in a Reader instead of a
        String, use .fromJson(Reader, TypeToken) instead.
        
        An exception is thrown if the JSON string has multiple top-level JSON elements, or if there
        is trailing data. Use .fromJson(JsonReader, TypeToken) if this behavior is not desired.
        
        Type `<T>`: the type of the desired object

        Arguments
        - json: the string from which the object is to be deserialized
        - typeOfT: The specific genericized type of src. You should create an anonymous subclass of
            `TypeToken` with the specific generic type arguments. For example, to get the type
            for `Collection<Foo>`, you should use:
            ```
        new TypeToken&lt;Collection&lt;Foo&gt;&gt;(){}
        ```

        Returns
        - an object of type T from the string. Returns `null` if `json` is `null` or if `json` is empty.

        Raises
        - JsonSyntaxException: if json is not a valid representation for an object of the type
            typeOfT

        See
        - .fromJson(String, Class)

        Since
        - 2.10
        """
        ...


    def fromJson(self, json: "Reader", classOfT: type["T"]) -> "T":
        """
        This method deserializes the JSON read from the specified reader into an object of the
        specified class. It is not suitable to use if the specified class is a generic type since it
        will not have the generic type information because of the Type Erasure feature of Java.
        Therefore, this method should not be used if the desired type is a generic type. Note that this
        method works fine if any of the fields of the specified object are generics, just the object
        itself should not be a generic type. For the cases when the object is of generic type, invoke
        .fromJson(Reader, TypeToken). If you have the JSON in a String form instead of a Reader, use .fromJson(String, Class) instead.
        
        An exception is thrown if the JSON data has multiple top-level JSON elements, or if there is
        trailing data. Use .fromJson(JsonReader, Type) if this behavior is not desired.
        
        Type `<T>`: the type of the desired object

        Arguments
        - json: the reader producing the JSON from which the object is to be deserialized.
        - classOfT: the class of T

        Returns
        - an object of type T from the Reader. Returns `null` if `json` is at EOF.

        Raises
        - JsonIOException: if there was a problem reading from the Reader
        - JsonSyntaxException: if json is not a valid representation for an object of type typeOfT

        See
        - .fromJson(Reader, TypeToken)

        Since
        - 1.2
        """
        ...


    def fromJson(self, json: "Reader", typeOfT: "Type") -> "T":
        """
        This method deserializes the JSON read from the specified reader into an object of the
        specified type. This method is useful if the specified object is a generic type. For
        non-generic objects, use .fromJson(Reader, Class) instead. If you have the JSON in a
        String form instead of a Reader, use .fromJson(String, Type) instead.
        
        Since `Type` is not parameterized by T, this method is not type-safe and should be
        used carefully. If you are creating the `Type` from a TypeToken, prefer using
        .fromJson(Reader, TypeToken) instead since its return type is based on the `TypeToken` and is therefore more type-safe.
        
        An exception is thrown if the JSON data has multiple top-level JSON elements, or if there is
        trailing data. Use .fromJson(JsonReader, Type) if this behavior is not desired.
        
        Type `<T>`: the type of the desired object

        Arguments
        - json: the reader producing JSON from which the object is to be deserialized
        - typeOfT: The specific genericized type of src

        Returns
        - an object of type T from the Reader. Returns `null` if `json` is at EOF.

        Raises
        - JsonIOException: if there was a problem reading from the Reader
        - JsonSyntaxException: if json is not a valid representation for an object of type typeOfT

        See
        - .fromJson(Reader, TypeToken)

        Since
        - 1.2
        """
        ...


    def fromJson(self, json: "Reader", typeOfT: "TypeToken"["T"]) -> "T":
        """
        This method deserializes the JSON read from the specified reader into an object of the
        specified type. This method is useful if the specified object is a generic type. For
        non-generic objects, use .fromJson(Reader, Class) instead. If you have the JSON in a
        String form instead of a Reader, use .fromJson(String, TypeToken) instead.
        
        An exception is thrown if the JSON data has multiple top-level JSON elements, or if there is
        trailing data. Use .fromJson(JsonReader, TypeToken) if this behavior is not desired.
        
        Type `<T>`: the type of the desired object

        Arguments
        - json: the reader producing JSON from which the object is to be deserialized
        - typeOfT: The specific genericized type of src. You should create an anonymous subclass of
            `TypeToken` with the specific generic type arguments. For example, to get the type
            for `Collection<Foo>`, you should use:
            ```
        new TypeToken&lt;Collection&lt;Foo&gt;&gt;(){}
        ```

        Returns
        - an object of type T from the Reader. Returns `null` if `json` is at EOF.

        Raises
        - JsonIOException: if there was a problem reading from the Reader
        - JsonSyntaxException: if json is not a valid representation for an object of type of
            typeOfT

        See
        - .fromJson(Reader, Class)

        Since
        - 2.10
        """
        ...


    def fromJson(self, reader: "JsonReader", typeOfT: "Type") -> "T":
        """
        Reads the next JSON value from `reader` and converts it to an object of type `typeOfT`. Returns `null`, if the `reader` is at EOF.
        
        Since `Type` is not parameterized by T, this method is not type-safe and should be
        used carefully. If you are creating the `Type` from a TypeToken, prefer using
        .fromJson(JsonReader, TypeToken) instead since its return type is based on the `TypeToken` and is therefore more type-safe. If the provided type is a `Class` the `TypeToken` can be created with TypeToken.get(Class).
        
        Unlike the other `fromJson` methods, no exception is thrown if the JSON data has
        multiple top-level JSON elements, or if there is trailing data.
        
        If the `Gson` instance has an GsonBuilder.setStrictness(Strictness)
        explicit strictness setting, this setting will be used for reading the JSON regardless of the
        JsonReader.getStrictness() strictness of the provided JsonReader. For
        legacy reasons, if the `Gson` instance has no explicit strictness setting and the reader
        does not have the strictness Strictness.STRICT, the JSON will be written in Strictness.LENIENT mode.
        Note that in all cases the old strictness setting of the reader will be restored when this
        method returns.
        
        Type `<T>`: the type of the desired object

        Arguments
        - reader: the reader whose next JSON value should be deserialized
        - typeOfT: The specific genericized type of src

        Returns
        - an object of type T from the JsonReader. Returns `null` if `reader` is at
            EOF.

        Raises
        - JsonIOException: if there was a problem reading from the JsonReader
        - JsonSyntaxException: if json is not a valid representation for an object of type typeOfT

        See
        - .fromJson(JsonReader, TypeToken)
        """
        ...


    def fromJson(self, reader: "JsonReader", typeOfT: "TypeToken"["T"]) -> "T":
        """
        Reads the next JSON value from `reader` and converts it to an object of type `typeOfT`. Returns `null`, if the `reader` is at EOF. This method is useful if the
        specified object is a generic type. For non-generic objects, .fromJson(JsonReader,
        Type) can be called, or TypeToken.get(Class) can be used to create the type token.
        
        Unlike the other `fromJson` methods, no exception is thrown if the JSON data has
        multiple top-level JSON elements, or if there is trailing data.
        
        If the `Gson` instance has an GsonBuilder.setStrictness(Strictness)
        explicit strictness setting, this setting will be used for reading the JSON regardless of the
        JsonReader.getStrictness() strictness of the provided JsonReader. For
        legacy reasons, if the `Gson` instance has no explicit strictness setting and the reader
        does not have the strictness Strictness.STRICT, the JSON will be written in Strictness.LENIENT mode.
        Note that in all cases the old strictness setting of the reader will be restored when this
        method returns.
        
        Type `<T>`: the type of the desired object

        Arguments
        - reader: the reader whose next JSON value should be deserialized
        - typeOfT: The specific genericized type of src. You should create an anonymous subclass of
            `TypeToken` with the specific generic type arguments. For example, to get the type
            for `Collection<Foo>`, you should use:
            ```
        new TypeToken&lt;Collection&lt;Foo&gt;&gt;(){}
        ```

        Returns
        - an object of type T from the JsonReader. Returns `null` if `reader` is at
            EOF.

        Raises
        - JsonIOException: if there was a problem reading from the JsonReader
        - JsonSyntaxException: if json is not a valid representation for an object of the type
            typeOfT

        See
        - .fromJson(JsonReader, Type)

        Since
        - 2.10
        """
        ...


    def fromJson(self, json: "JsonElement", classOfT: type["T"]) -> "T":
        """
        This method deserializes the JSON read from the specified parse tree into an object of the
        specified type. It is not suitable to use if the specified class is a generic type since it
        will not have the generic type information because of the Type Erasure feature of Java.
        Therefore, this method should not be used if the desired type is a generic type. Note that this
        method works fine if any of the fields of the specified object are generics, just the object
        itself should not be a generic type. For the cases when the object is of generic type, invoke
        .fromJson(JsonElement, TypeToken).
        
        Type `<T>`: the type of the desired object

        Arguments
        - json: the root of the parse tree of JsonElements from which the object is to be
            deserialized
        - classOfT: The class of T

        Returns
        - an object of type T from the JSON. Returns `null` if `json` is `null`
            or if `json` is empty.

        Raises
        - JsonSyntaxException: if json is not a valid representation for an object of type
            classOfT

        See
        - .fromJson(JsonElement, TypeToken)

        Since
        - 1.3
        """
        ...


    def fromJson(self, json: "JsonElement", typeOfT: "Type") -> "T":
        """
        This method deserializes the JSON read from the specified parse tree into an object of the
        specified type. This method is useful if the specified object is a generic type. For
        non-generic objects, use .fromJson(JsonElement, Class) instead.
        
        Since `Type` is not parameterized by T, this method is not type-safe and should be
        used carefully. If you are creating the `Type` from a TypeToken, prefer using
        .fromJson(JsonElement, TypeToken) instead since its return type is based on the `TypeToken` and is therefore more type-safe.
        
        Type `<T>`: the type of the desired object

        Arguments
        - json: the root of the parse tree of JsonElements from which the object is to be
            deserialized
        - typeOfT: The specific genericized type of src

        Returns
        - an object of type T from the JSON. Returns `null` if `json` is `null`
            or if `json` is empty.

        Raises
        - JsonSyntaxException: if json is not a valid representation for an object of type typeOfT

        See
        - .fromJson(JsonElement, TypeToken)

        Since
        - 1.3
        """
        ...


    def fromJson(self, json: "JsonElement", typeOfT: "TypeToken"["T"]) -> "T":
        """
        This method deserializes the JSON read from the specified parse tree into an object of the
        specified type. This method is useful if the specified object is a generic type. For
        non-generic objects, use .fromJson(JsonElement, Class) instead.
        
        Type `<T>`: the type of the desired object

        Arguments
        - json: the root of the parse tree of JsonElements from which the object is to be
            deserialized
        - typeOfT: The specific genericized type of src. You should create an anonymous subclass of
            `TypeToken` with the specific generic type arguments. For example, to get the type
            for `Collection<Foo>`, you should use:
            ```
        new TypeToken&lt;Collection&lt;Foo&gt;&gt;(){}
        ```

        Returns
        - an object of type T from the JSON. Returns `null` if `json` is `null`
            or if `json` is empty.

        Raises
        - JsonSyntaxException: if json is not a valid representation for an object of type typeOfT

        See
        - .fromJson(JsonElement, Class)

        Since
        - 2.10
        """
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file com.google.common.cache.RemovalNotification

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.cache import *
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class RemovalNotification(SimpleImmutableEntry):
    """
    A notification of the removal of a single entry. The key and/or value may be null if they were
    already garbage collected.
    
    Like other `Entry` instances associated with `CacheBuilder`, this class holds
    strong references to the key and value, regardless of the type of references the cache may be
    using.

    Author(s)
    - Charles Fry

    Since
    - 10.0
    """

    @staticmethod
    def create(key: "K", value: "V", cause: "RemovalCause") -> "RemovalNotification"["K", "V"]:
        """
        Creates a new `RemovalNotification` for the given `key`/`value` pair, with
        the given `cause` for the removal. The `key` and/or `value` may be `null` if they were already garbage collected.

        Since
        - 19.0
        """
        ...


    def getCause(self) -> "RemovalCause":
        """
        Returns the cause for which the entry was removed.
        """
        ...


    def wasEvicted(self) -> bool:
        """
        Returns `True` if there was an automatic removal due to eviction (the cause is neither
        RemovalCause.EXPLICIT nor RemovalCause.REPLACED).
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.external.biz.base64Coder.Base64Coder

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.external.biz.base64Coder import *
from typing import Any, Callable, Iterable, Tuple


class Base64Coder:
    """
    A Base64 encoder/decoder.
    
    
    This class is used to encode and decode data in Base64 format as described in RFC 1521.
    
    
    Project home page: <a href="http://www.source-code.biz/base64coder/java/">www.
    source-code.biz/base64coder/java</a>
    Author: Christian d'Heureuse, Inventec Informatik AG, Zurich, Switzerland
    Multi-licensed: EPL / LGPL / GPL / AL / BSD.
    """

    @staticmethod
    def encodeString(s: str) -> str:
        """
        Encodes a string into Base64 format. No blanks or line breaks are inserted.

        Arguments
        - s: A String to be encoded.

        Returns
        - A String containing the Base64 encoded data.
        """
        ...


    @staticmethod
    def encodeLines(in: list[int]) -> str:
        """
        Encodes a byte array into Base 64 format and breaks the output into lines of 76 characters.
        This method is compatible with `sun.misc.BASE64Encoder.encodeBuffer(byte[])`.

        Arguments
        - in: An array containing the data bytes to be encoded.

        Returns
        - A String containing the Base64 encoded data, broken into lines.
        """
        ...


    @staticmethod
    def encodeLines(in: list[int], iOff: int, iLen: int, lineLen: int, lineSeparator: str) -> str:
        """
        Encodes a byte array into Base 64 format and breaks the output into lines.

        Arguments
        - in: An array containing the data bytes to be encoded.
        - iOff: Offset of the first byte in `in` to be processed.
        - iLen: Number of bytes to be processed in `in`, starting at `iOff`.
        - lineLen: Line length for the output data. Should be a multiple of 4.
        - lineSeparator: The line separator to be used to separate the output lines.

        Returns
        - A String containing the Base64 encoded data, broken into lines.
        """
        ...


    @staticmethod
    def encode(in: list[int]) -> list[str]:
        """
        Encodes a byte array into Base64 format. No blanks or line breaks are inserted in the output.

        Arguments
        - in: An array containing the data bytes to be encoded.

        Returns
        - A character array containing the Base64 encoded data.
        """
        ...


    @staticmethod
    def encode(in: list[int], iLen: int) -> list[str]:
        """
        Encodes a byte array into Base64 format. No blanks or line breaks are inserted in the output.

        Arguments
        - in: An array containing the data bytes to be encoded.
        - iLen: Number of bytes to process in `in`.

        Returns
        - A character array containing the Base64 encoded data.
        """
        ...


    @staticmethod
    def encode(in: list[int], iOff: int, iLen: int) -> list[str]:
        """
        Encodes a byte array into Base64 format. No blanks or line breaks are inserted in the output.

        Arguments
        - in: An array containing the data bytes to be encoded.
        - iOff: Offset of the first byte in `in` to be processed.
        - iLen: Number of bytes to process in `in`, starting at `iOff`.

        Returns
        - A character array containing the Base64 encoded data.
        """
        ...


    @staticmethod
    def decodeString(s: str) -> str:
        """
        Decodes a string from Base64 format. No blanks or line breaks are allowed within the Base64
        encoded input data.

        Arguments
        - s: A Base64 String to be decoded.

        Returns
        - A String containing the decoded data.

        Raises
        - IllegalArgumentException: If the input is not valid Base64 encoded data.
        """
        ...


    @staticmethod
    def decodeLines(s: str) -> list[int]:
        """
        Decodes a byte array from Base64 format and ignores line separators, tabs and blanks. CR, LF,
        Tab and Space characters are ignored in the input data. This method is compatible with
        `sun.misc.BASE64Decoder.decodeBuffer(String)`.

        Arguments
        - s: A Base64 String to be decoded.

        Returns
        - An array containing the decoded data bytes.

        Raises
        - IllegalArgumentException: If the input is not valid Base64 encoded data.
        """
        ...


    @staticmethod
    def decode(s: str) -> list[int]:
        """
        Decodes a byte array from Base64 format. No blanks or line breaks are allowed within the Base64
        encoded input data.

        Arguments
        - s: A Base64 String to be decoded.

        Returns
        - An array containing the decoded data bytes.

        Raises
        - IllegalArgumentException: If the input is not valid Base64 encoded data.
        """
        ...


    @staticmethod
    def decode(in: list[str]) -> list[int]:
        """
        Decodes a byte array from Base64 format. No blanks or line breaks are allowed within the Base64
        encoded input data.

        Arguments
        - in: A character array containing the Base64 encoded data.

        Returns
        - An array containing the decoded data bytes.

        Raises
        - IllegalArgumentException: If the input is not valid Base64 encoded data.
        """
        ...


    @staticmethod
    def decode(in: list[str], iOff: int, iLen: int) -> list[int]:
        """
        Decodes a byte array from Base64 format. No blanks or line breaks are allowed within the Base64
        encoded input data.

        Arguments
        - in: A character array containing the Base64 encoded data.
        - iOff: Offset of the first character in `in` to be processed.
        - iLen: Number of characters to process in `in`, starting at `iOff`.

        Returns
        - An array containing the decoded data bytes.

        Raises
        - IllegalArgumentException: If the input is not valid Base64 encoded data.
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Boat

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import Material
from org.bukkit import TreeSpecies
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Boat(Vehicle):
    """
    Represents a boat entity.
    """

    def getWoodType(self) -> "TreeSpecies":
        """
        Gets the wood type of the boat.

        Returns
        - the wood type

        Deprecated
        - deprecated in favor of .getBoatType()
        """
        ...


    def setWoodType(self, species: "TreeSpecies") -> None:
        """
        Sets the wood type of the boat.

        Arguments
        - species: the new wood type

        Deprecated
        - deprecated in favor of .setBoatType(Type)
        """
        ...


    def getBoatType(self) -> "Type":
        """
        Gets the type of the boat.

        Returns
        - the boat type

        Deprecated
        - different boats types are now different entity types
        """
        ...


    def setBoatType(self, type: "Type") -> None:
        """
        Sets the type of the boat.

        Arguments
        - type: the new type

        Deprecated
        - different boats types are now different entity types
        """
        ...


    def getMaxSpeed(self) -> float:
        """
        Gets the maximum speed of a boat. The speed is unrelated to the
        velocity.

        Returns
        - The max speed.

        Deprecated
        - boats are complex and many of these methods do not work correctly across multiple versions.
        """
        ...


    def setMaxSpeed(self, speed: float) -> None:
        """
        Sets the maximum speed of a boat. Must be nonnegative. Default is 0.4D.

        Arguments
        - speed: The max speed.

        Deprecated
        - boats are complex and many of these methods do not work correctly across multiple versions.
        """
        ...


    def getOccupiedDeceleration(self) -> float:
        """
        Gets the deceleration rate (newSpeed = curSpeed * rate) of occupied
        boats. The default is 0.2.

        Returns
        - The rate of deceleration

        Deprecated
        - boats are complex and many of these methods do not work correctly across multiple versions.
        """
        ...


    def setOccupiedDeceleration(self, rate: float) -> None:
        """
        Sets the deceleration rate (newSpeed = curSpeed * rate) of occupied
        boats. Setting this to a higher value allows for quicker acceleration.
        The default is 0.2.

        Arguments
        - rate: deceleration rate

        Deprecated
        - boats are complex and many of these methods do not work correctly across multiple versions.
        """
        ...


    def getUnoccupiedDeceleration(self) -> float:
        """
        Gets the deceleration rate (newSpeed = curSpeed * rate) of unoccupied
        boats. The default is -1. Values below 0 indicate that no additional
        deceleration is imposed.

        Returns
        - The rate of deceleration

        Deprecated
        - boats are complex and many of these methods do not work correctly across multiple versions.
        """
        ...


    def setUnoccupiedDeceleration(self, rate: float) -> None:
        """
        Sets the deceleration rate (newSpeed = curSpeed * rate) of unoccupied
        boats. Setting this to a higher value allows for quicker deceleration
        of boats when a player disembarks. The default is -1. Values below 0
        indicate that no additional deceleration is imposed.

        Arguments
        - rate: deceleration rate

        Deprecated
        - boats are complex and many of these methods do not work correctly across multiple versions.
        """
        ...


    def getWorkOnLand(self) -> bool:
        """
        Get whether boats can work on land.

        Returns
        - whether boats can work on land

        Deprecated
        - boats are complex and many of these methods do not work correctly across multiple versions.
        """
        ...


    def setWorkOnLand(self, workOnLand: bool) -> None:
        """
        Set whether boats can work on land.

        Arguments
        - workOnLand: whether boats can work on land

        Deprecated
        - boats are complex and many of these methods do not work correctly across multiple versions.
        """
        ...


    def getStatus(self) -> "Status":
        """
        Gets the status of the boat.

        Returns
        - the status
        """
        ...


    class Type(Enum):
        """
        Represents the type of boats.

        Deprecated
        - different boats types are now different entity types
        """

        OAK = (Material.OAK_PLANKS)
        SPRUCE = (Material.SPRUCE_PLANKS)
        BIRCH = (Material.BIRCH_PLANKS)
        JUNGLE = (Material.JUNGLE_PLANKS)
        ACACIA = (Material.ACACIA_PLANKS)
        CHERRY = (Material.CHERRY_PLANKS)
        DARK_OAK = (Material.DARK_OAK_PLANKS)
        MANGROVE = (Material.MANGROVE_PLANKS)
        BAMBOO = (Material.BAMBOO_PLANKS)


        def getMaterial(self) -> "Material":
            """
            Gets the material of the boat type.

            Returns
            - a material
            """
            ...


    class Status(Enum):
        """
        Represents the status of the boat.
        """

        IN_WATER = 0
        UNDER_WATER = 1
        UNDER_FLOWING_WATER = 2
        ON_LAND = 3
        IN_AIR = 4



"""
Python module generated from Java source file org.bukkit.inventory.ItemFlag

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.inventory import *
from typing import Any, Callable, Iterable, Tuple


class ItemFlag(Enum):
    """
    A ItemFlag can hide some Attributes from ItemStacks
    """

    HIDE_ENCHANTS = 0
    """
    Setting to show/hide enchants
    """
    HIDE_ATTRIBUTES = 1
    """
    Setting to show/hide Attributes like Damage
    """
    HIDE_UNBREAKABLE = 2
    """
    Setting to show/hide the unbreakable State
    """
    HIDE_DESTROYS = 3
    """
    Setting to show/hide what the ItemStack can break/destroy
    """
    HIDE_PLACED_ON = 4
    """
    Setting to show/hide where this ItemStack can be build/placed on
    """
    HIDE_ADDITIONAL_TOOLTIP = 5
    """
    Setting to show/hide potion effects, book and firework information, map
    tooltips, patterns of banners, and enchantments of enchanted books.
    """
    HIDE_DYE = 6
    """
    Setting to show/hide dyes from colored leather armor.
    """
    HIDE_ARMOR_TRIM = 7
    """
    Setting to show/hide armor trim from leather armor.
    """



from .Permission import Permission
from .PermissionAttachment import PermissionAttachment
from .PermissionAttachmentInfo import PermissionAttachmentInfo
from .ServerOperator import ServerOperator
from .PermissibleBase import PermissibleBase
from .Permissible import Permissible
from .PermissionRemovedExecutor import PermissionRemovedExecutor
from .PermissionDefault import PermissionDefault


"""
Python module generated from Java source file com.google.common.collect.RegularImmutableBiMap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.collect import *
from com.google.common.collect.ImmutableMapEntry import NonTerminalImmutableBiMapEntry
from com.google.common.collect.RegularImmutableMap import BucketOverflowException
from com.google.errorprone.annotations.concurrent import LazyInit
from com.google.j2objc.annotations import RetainedWith
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import Serializable
from java.util.function import BiConsumer
from java.util.function import Consumer
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class RegularImmutableBiMap(ImmutableBiMap):
    """
    Bimap with zero or more mappings.

    Author(s)
    - Louis Wasserman
    """

    def get(self, key: "Object") -> "V":
        ...


    def forEach(self, action: "BiConsumer"["K", "V"]) -> None:
        ...


    def hashCode(self) -> int:
        ...


    def size(self) -> int:
        ...


    def inverse(self) -> "ImmutableBiMap"["V", "K"]:
        ...



"""
Python module generated from Java source file org.bukkit.event.block.EntityBlockFormEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.block import BlockState
from org.bukkit.entity import Entity
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class EntityBlockFormEvent(BlockFormEvent):
    """
    Called when a block is formed by entities.
    
    Examples:
    
    - Snow formed by a org.bukkit.entity.Snowman.
    - Frosted Ice formed by the Frost Walker enchantment.
    """

    def __init__(self, entity: "Entity", block: "Block", blockstate: "BlockState"):
        ...


    def getEntity(self) -> "Entity":
        """
        Get the entity that formed the block.

        Returns
        - Entity involved in event
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.TropicalFishBucketMeta

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import DyeColor
from org.bukkit.entity import TropicalFish
from org.bukkit.inventory.meta import *
from typing import Any, Callable, Iterable, Tuple


class TropicalFishBucketMeta(ItemMeta):
    """
    Represents a bucket of tropical fish.
    """

    def getPatternColor(self) -> "DyeColor":
        """
        Gets the color of the fish's pattern.
        
        Plugins should check that hasVariant() returns `True` before
        calling this method.

        Returns
        - pattern color
        """
        ...


    def setPatternColor(self, color: "DyeColor") -> None:
        """
        Sets the color of the fish's pattern.
        
        Setting this when hasVariant() returns `False` will initialize
        all other values to unspecified defaults.

        Arguments
        - color: pattern color
        """
        ...


    def getBodyColor(self) -> "DyeColor":
        """
        Gets the color of the fish's body.
        
        Plugins should check that hasVariant() returns `True` before
        calling this method.

        Returns
        - pattern color
        """
        ...


    def setBodyColor(self, color: "DyeColor") -> None:
        """
        Sets the color of the fish's body.
        
        Setting this when hasVariant() returns `False` will initialize
        all other values to unspecified defaults.

        Arguments
        - color: body color
        """
        ...


    def getPattern(self) -> "TropicalFish.Pattern":
        """
        Gets the fish's pattern.
        
        Plugins should check that hasVariant() returns `True` before
        calling this method.

        Returns
        - pattern
        """
        ...


    def setPattern(self, pattern: "TropicalFish.Pattern") -> None:
        """
        Sets the fish's pattern.
        
        Setting this when hasVariant() returns `False` will initialize
        all other values to unspecified defaults.

        Arguments
        - pattern: new pattern
        """
        ...


    def hasVariant(self) -> bool:
        """
        Checks for existence of a variant tag indicating a specific fish will be
        spawned.

        Returns
        - if there is a variant
        """
        ...


    def clone(self) -> "TropicalFishBucketMeta":
        ...



"""
Python module generated from Java source file com.google.common.graph.MultiEdgesConnecting

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import AbstractIterator
from com.google.common.collect import UnmodifiableIterator
from com.google.common.graph import *
from java.util import AbstractSet
from java.util import Iterator
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class MultiEdgesConnecting(AbstractSet):
    """
    A class to represent the set of edges connecting an (implicit) origin node to a target node.
    
    The .outEdgeToNode map allows this class to work on networks with parallel edges. See
    EdgesConnecting for a class that is more efficient but forbids parallel edges.
    
    Type `<E>`: Edge parameter type

    Author(s)
    - James Sexton
    """

    def iterator(self) -> "UnmodifiableIterator"["E"]:
        ...


    def contains(self, edge: "Object") -> bool:
        ...



"""
Python module generated from Java source file java.util.concurrent.RejectedExecutionException

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util.concurrent import *
from typing import Any, Callable, Iterable, Tuple


class RejectedExecutionException(RuntimeException):
    """
    Exception thrown by an Executor when a task cannot be
    accepted for execution.

    Author(s)
    - Doug Lea

    Since
    - 1.5
    """

    def __init__(self):
        """
        Constructs a `RejectedExecutionException` with no detail message.
        The cause is not initialized, and may subsequently be
        initialized by a call to .initCause(Throwable) initCause.
        """
        ...


    def __init__(self, message: str):
        """
        Constructs a `RejectedExecutionException` with the
        specified detail message. The cause is not initialized, and may
        subsequently be initialized by a call to .initCause(Throwable) initCause.

        Arguments
        - message: the detail message
        """
        ...


    def __init__(self, message: str, cause: "Throwable"):
        """
        Constructs a `RejectedExecutionException` with the
        specified detail message and cause.

        Arguments
        - message: the detail message
        - cause: the cause (which is saved for later retrieval by the
                .getCause() method)
        """
        ...


    def __init__(self, cause: "Throwable"):
        """
        Constructs a `RejectedExecutionException` with the
        specified cause.  The detail message is set to `(cause ==
        null ? null : cause.toString())` (which typically contains
        the class and detail message of `cause`).

        Arguments
        - cause: the cause (which is saved for later retrieval by the
                .getCause() method)
        """
        ...



"""
Python module generated from Java source file org.bukkit.util.OldEnum

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.util import *
from typing import Any, Callable, Iterable, Tuple


class OldEnum(Comparable):
    """
    Class which holds common methods which are present in an enum.
    
    Type `<T>`: the type of the old enum.

    Deprecated
    - only for backwards compatibility.
    """

    def compareTo(self, other: "T") -> int:
        """
        Arguments
        - other: to compare to.

        Returns
        - negative if this old enum is lower, zero if equal and positive if
        higher than the given old enum.

        Deprecated
        - only for backwards compatibility, old enums can not be
        compared.
        """
        ...


    def name(self) -> str:
        """
        Returns
        - the name of the old enum.

        Deprecated
        - only for backwards compatibility.
        """
        ...


    def ordinal(self) -> int:
        """
        Returns
        - the ordinal of the old enum.

        Deprecated
        - only for backwards compatibility, it is not guaranteed that
        an old enum always has the same ordinal.
        """
        ...



"""
Python module generated from Java source file org.bukkit.damage.DamageEffect

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from org.bukkit import Bukkit
from org.bukkit import Sound
from org.bukkit.damage import *
from typing import Any, Callable, Iterable, Tuple


class DamageEffect:
    """
    Represents a type of effect that occurs when damage is inflicted. Currently,
    effects only determine the sound that plays.
    """

    HURT = getDamageEffect("hurt")
    """
    The default damage effect.
    """
    THORNS = getDamageEffect("thorns")
    """
    Thorns.
    """
    DROWNING = getDamageEffect("drowning")
    """
    Drowning.
    """
    BURNING = getDamageEffect("burning")
    """
    A single burn tick (fire, lava, etc.).
    """
    POKING = getDamageEffect("poking")
    """
    Poked by a berry bush.
    """
    FREEZING = getDamageEffect("freezing")
    """
    Freeze tick (powder snow).
    """


    @staticmethod
    def getDamageEffect(key: str) -> "DamageEffect":
        ...


    def getSound(self) -> "Sound":
        """
        Get the Sound played for this DamageEffect.

        Returns
        - the sound
        """
        ...



"""
Python module generated from Java source file com.google.common.annotations.VisibleForTesting

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import *
from typing import Any, Callable, Iterable, Tuple


class VisibleForTesting:
    """
    Annotates a program element that exists, or is more widely visible than otherwise necessary, only
    for use in test code.
    
    **Do not use this interface** for public or protected declarations: it is a fig leaf for
    bad design, and it does not prevent anyone from using the declaration---and experience has shown
    that they will. If the method breaks the encapsulation of its class, then its internal
    representation will be hard to change. Instead, use <a
    href="http://errorprone.info/bugpattern/RestrictedApi">RestrictedApiChecker</a>, which enforces
    fine-grained visibility policies.

    Author(s)
    - Johannes Henkel
    """





"""
Python module generated from Java source file com.google.common.io.PatternFilenameFilter

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.base import Preconditions
from com.google.common.io import *
from java.io import File
from java.io import FilenameFilter
from java.util.regex import Pattern
from java.util.regex import PatternSyntaxException
from typing import Any, Callable, Iterable, Tuple


class PatternFilenameFilter(FilenameFilter):
    """
    File name filter that only accepts files matching a regular expression. This class is thread-safe
    and immutable.

    Author(s)
    - Apple Chow

    Since
    - 1.0
    """

    def __init__(self, patternStr: str):
        """
        Constructs a pattern file name filter object.

        Arguments
        - patternStr: the pattern string on which to filter file names

        Raises
        - PatternSyntaxException: if pattern compilation fails (runtime)
        """
        ...


    def __init__(self, pattern: "Pattern"):
        """
        Constructs a pattern file name filter object.

        Arguments
        - pattern: the pattern on which to filter file names
        """
        ...


    def accept(self, dir: "File", fileName: str) -> bool:
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.NoteBlock

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Instrument
from org.bukkit import Note
from org.bukkit.block.data import Powerable
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class NoteBlock(Powerable):
    """
    'instrument' is the type of sound made when this note block is activated.
    
    'note' is the specified tuned pitch that the instrument will be played in.
    """

    def getInstrument(self) -> "Instrument":
        """
        Gets the value of the 'instrument' property.

        Returns
        - the 'instrument' value
        """
        ...


    def setInstrument(self, instrument: "Instrument") -> None:
        """
        Sets the value of the 'instrument' property.

        Arguments
        - instrument: the new 'instrument' value
        """
        ...


    def getNote(self) -> "Note":
        """
        Gets the value of the 'note' property.

        Returns
        - the 'note' value
        """
        ...


    def setNote(self, note: "Note") -> None:
        """
        Sets the value of the 'note' property.

        Arguments
        - note: the new 'note' value
        """
        ...



"""
Python module generated from Java source file org.bukkit.structure.Structure

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Random
from org.bukkit import Location
from org.bukkit import RegionAccessor
from org.bukkit.block.structure import Mirror
from org.bukkit.block.structure import StructureRotation
from org.bukkit.entity import Entity
from org.bukkit.persistence import PersistentDataHolder
from org.bukkit.structure import *
from org.bukkit.util import BlockTransformer
from org.bukkit.util import BlockVector
from org.bukkit.util import EntityTransformer
from typing import Any, Callable, Iterable, Tuple


class Structure(PersistentDataHolder):
    """
    Represents a structure.
    
    A structure is a mutable template of captured blocks and entities that can be
    copied back into the world. The StructureManager, retrieved via
    org.bukkit.Server.getStructureManager(), allows you to create new
    structures, load existing structures, and save structures.
    
    In order for a structure to be usable by structure blocks, it needs to be
    null StructureManager.registerStructure(org.bukkit.NamespacedKey, Structure)
    registered with the StructureManager, or located in the primary
    world folder, a DataPack, or the server's own default resources, so that the
    StructureManager can find it.
    """

    def getSize(self) -> "BlockVector":
        """
        Gets the current size of the structure.
        
        The size of the structure may not be fixed.

        Returns
        - A new vector that represents the size of the structure along each
        axis.
        """
        ...


    def getPalettes(self) -> list["Palette"]:
        """
        Gets a list of available block palettes.

        Returns
        - a list of available variants of this structure.
        """
        ...


    def getPaletteCount(self) -> int:
        """
        Gets the number of palettes in this structure.

        Returns
        - The number of palettes in this structure
        """
        ...


    def getEntities(self) -> list["Entity"]:
        """
        Gets a list of entities that have been included in the Structure.
        
        The entity positions are offsets relative to the structure's position
        that is provided once the structure is placed into the world.

        Returns
        - a list of Entities included in the Structure.
        """
        ...


    def getEntityCount(self) -> int:
        """
        Gets the number of entities in this structure.

        Returns
        - The number of entities in this structure
        """
        ...


    def place(self, location: "Location", includeEntities: bool, structureRotation: "StructureRotation", mirror: "Mirror", palette: int, integrity: float, random: "Random") -> None:
        """
        Place a structure in the world.

        Arguments
        - location: The location to place the structure at.
        - includeEntities: If the entities present in the structure should be
        spawned.
        - structureRotation: The rotation of the structure.
        - mirror: The mirror settings of the structure.
        - palette: The palette index of the structure to use, starting at
        `0`, or `-1` to pick a random palette.
        - integrity: Determines how damaged the building should look by
        randomly skipping blocks to place. This value can range from 0 to 1. With
        0 removing all blocks and 1 spawning the structure in pristine condition.
        - random: The randomizer used for setting the structure's
        org.bukkit.loot.LootTables and integrity.
        """
        ...


    def place(self, location: "Location", includeEntities: bool, structureRotation: "StructureRotation", mirror: "Mirror", palette: int, integrity: float, random: "Random", blockTransformers: Iterable["BlockTransformer"], entityTransformers: Iterable["EntityTransformer"]) -> None:
        """
        Place a structure in the world.

        Arguments
        - location: The location to place the structure at.
        - includeEntities: If the entities present in the structure should be
        spawned.
        - structureRotation: The rotation of the structure.
        - mirror: The mirror settings of the structure.
        - palette: The palette index of the structure to use, starting at
        `0`, or `-1` to pick a random palette.
        - integrity: Determines how damaged the building should look by
        randomly skipping blocks to place. This value can range from 0 to 1. With
        0 removing all blocks and 1 spawning the structure in pristine condition.
        - random: The randomizer used for setting the structure's
        org.bukkit.loot.LootTables and integrity.
        - blockTransformers: A collection of BlockTransformers to apply to the structure.
        - entityTransformers: A collection of EntityTransformers to apply to the structure.
        """
        ...


    def place(self, regionAccessor: "RegionAccessor", location: "BlockVector", includeEntities: bool, structureRotation: "StructureRotation", mirror: "Mirror", palette: int, integrity: float, random: "Random") -> None:
        """
        Place a structure in the world.

        Arguments
        - regionAccessor: The world to place the structure in.
        - location: The location to place the structure at.
        - includeEntities: If the entities present in the structure should be
        spawned.
        - structureRotation: The rotation of the structure.
        - mirror: The mirror settings of the structure.
        - palette: The palette index of the structure to use, starting at
        `0`, or `-1` to pick a random palette.
        - integrity: Determines how damaged the building should look by
        randomly skipping blocks to place. This value can range from 0 to 1. With
        0 removing all blocks and 1 spawning the structure in pristine condition.
        - random: The randomizer used for setting the structure's
        org.bukkit.loot.LootTables and integrity.
        """
        ...


    def place(self, regionAccessor: "RegionAccessor", location: "BlockVector", includeEntities: bool, structureRotation: "StructureRotation", mirror: "Mirror", palette: int, integrity: float, random: "Random", blockTransformers: Iterable["BlockTransformer"], entityTransformers: Iterable["EntityTransformer"]) -> None:
        """
        Place a structure in the world.

        Arguments
        - regionAccessor: The world to place the structure in.
        - location: The location to place the structure at.
        - includeEntities: If the entities present in the structure should be
        spawned.
        - structureRotation: The rotation of the structure.
        - mirror: The mirror settings of the structure.
        - palette: The palette index of the structure to use, starting at
        `0`, or `-1` to pick a random palette.
        - integrity: Determines how damaged the building should look by
        randomly skipping blocks to place. This value can range from 0 to 1. With
        0 removing all blocks and 1 spawning the structure in pristine condition.
        - random: The randomizer used for setting the structure's
        org.bukkit.loot.LootTables and integrity.
        - blockTransformers: A collection of BlockTransformers to apply to the structure.
        - entityTransformers: A collection of EntityTransformers to apply to the structure.
        """
        ...


    def fill(self, corner1: "Location", corner2: "Location", includeEntities: bool) -> None:
        """
        Fills the structure from an area in a world. The origin and size will be
        calculated automatically from the two corners provided.
        
        Be careful as this will override the current data of the structure.
        
        Be aware that this method allows for creating structures larger than the
        48x48x48 size that Minecraft's Structure blocks support. Any structures
        saved this way can not be loaded by using a structure block. Using the
        API however will still work.

        Arguments
        - corner1: A corner of the structure.
        - corner2: The corner opposite from corner1.
        - includeEntities: True if entities should be included in the saved
        structure.
        """
        ...


    def fill(self, origin: "Location", size: "BlockVector", includeEntities: bool) -> None:
        """
        Fills the Structure from an area in a world, starting at the specified
        origin and extending in each axis according to the specified size vector.
        
        Be careful as this will override the current data of the structure.
        
        Be aware that this method allows for saving structures larger than the
        48x48x48 size that Minecraft's Structure blocks support. Any structures
        saved this way can not be loaded by using a structure block. Using the
        API however will still work.

        Arguments
        - origin: The origin of the structure.
        - size: The size of the structure, must be at least 1x1x1.
        - includeEntities: True if entities should be included in the saved
        structure.

        Raises
        - IllegalArgumentException: Thrown if size is smaller than 1x1x1
        """
        ...



"""
Python module generated from Java source file java.util.concurrent.ConcurrentLinkedQueue

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.invoke import MethodHandles
from java.lang.invoke import VarHandle
from java.util import AbstractQueue
from java.util import Arrays
from java.util import Iterator
from java.util import NoSuchElementException
from java.util import Objects
from java.util import Queue
from java.util import Spliterator
from java.util.concurrent import *
from java.util.function import Consumer
from java.util.function import Predicate
from typing import Any, Callable, Iterable, Tuple


class ConcurrentLinkedQueue(AbstractQueue, Queue, Serializable):
    """
    An unbounded thread-safe Queue queue based on linked nodes.
    This queue orders elements FIFO (first-in-first-out).
    The *head* of the queue is that element that has been on the
    queue the longest time.
    The *tail* of the queue is that element that has been on the
    queue the shortest time. New elements
    are inserted at the tail of the queue, and the queue retrieval
    operations obtain elements at the head of the queue.
    A `ConcurrentLinkedQueue` is an appropriate choice when
    many threads will share access to a common collection.
    Like most other concurrent collection implementations, this class
    does not permit the use of `null` elements.
    
    This implementation employs an efficient *non-blocking*
    algorithm based on one described in
    <a href="http://www.cs.rochester.edu/~scott/papers/1996_PODC_queues.pdf">
    Simple, Fast, and Practical Non-Blocking and Blocking Concurrent Queue
    Algorithms</a> by Maged M. Michael and Michael L. Scott.
    
    Iterators are *weakly consistent*, returning elements
    reflecting the state of the queue at some point at or since the
    creation of the iterator.  They do *not* throw java.util.ConcurrentModificationException, and may proceed concurrently
    with other operations.  Elements contained in the queue since the creation
    of the iterator will be returned exactly once.
    
    Beware that, unlike in most collections, the `size` method
    is *NOT* a constant-time operation. Because of the
    asynchronous nature of these queues, determining the current number
    of elements requires a traversal of the elements, and so may report
    inaccurate results if this collection is modified during traversal.
    
    Bulk operations that add, remove, or examine multiple elements,
    such as .addAll, .removeIf or .forEach,
    are *not* guaranteed to be performed atomically.
    For example, a `forEach` traversal concurrent with an `addAll` operation might observe only some of the added elements.
    
    This class and its iterator implement all of the *optional*
    methods of the Queue and Iterator interfaces.
    
    Memory consistency effects: As with other concurrent
    collections, actions in a thread prior to placing an object into a
    `ConcurrentLinkedQueue`
    <a href="package-summary.html#MemoryVisibility">*happen-before*</a>
    actions subsequent to the access or removal of that element from
    the `ConcurrentLinkedQueue` in another thread.
    
    This class is a member of the
    <a href="/java.base/java/util/package-summary.html#CollectionsFramework">
    Java Collections Framework</a>.
    
    Type `<E>`: the type of elements held in this queue

    Author(s)
    - Doug Lea

    Since
    - 1.5
    """

    def __init__(self):
        """
        Creates a `ConcurrentLinkedQueue` that is initially empty.
        """
        ...


    def __init__(self, c: Iterable["E"]):
        """
        Creates a `ConcurrentLinkedQueue`
        initially containing the elements of the given collection,
        added in traversal order of the collection's iterator.

        Arguments
        - c: the collection of elements to initially contain

        Raises
        - NullPointerException: if the specified collection or any
                of its elements are null
        """
        ...


    def add(self, e: "E") -> bool:
        """
        Inserts the specified element at the tail of this queue.
        As the queue is unbounded, this method will never throw
        IllegalStateException or return `False`.

        Returns
        - `True` (as specified by Collection.add)

        Raises
        - NullPointerException: if the specified element is null
        """
        ...


    def offer(self, e: "E") -> bool:
        """
        Inserts the specified element at the tail of this queue.
        As the queue is unbounded, this method will never return `False`.

        Returns
        - `True` (as specified by Queue.offer)

        Raises
        - NullPointerException: if the specified element is null
        """
        ...


    def poll(self) -> "E":
        ...


    def peek(self) -> "E":
        ...


    def isEmpty(self) -> bool:
        """
        Returns `True` if this queue contains no elements.

        Returns
        - `True` if this queue contains no elements
        """
        ...


    def size(self) -> int:
        """
        Returns the number of elements in this queue.  If this queue
        contains more than `Integer.MAX_VALUE` elements, returns
        `Integer.MAX_VALUE`.
        
        Beware that, unlike in most collections, this method is
        *NOT* a constant-time operation. Because of the
        asynchronous nature of these queues, determining the current
        number of elements requires an O(n) traversal.
        Additionally, if elements are added or removed during execution
        of this method, the returned result may be inaccurate.  Thus,
        this method is typically not very useful in concurrent
        applications.

        Returns
        - the number of elements in this queue
        """
        ...


    def contains(self, o: "Object") -> bool:
        """
        Returns `True` if this queue contains the specified element.
        More formally, returns `True` if and only if this queue contains
        at least one element `e` such that `o.equals(e)`.

        Arguments
        - o: object to be checked for containment in this queue

        Returns
        - `True` if this queue contains the specified element
        """
        ...


    def remove(self, o: "Object") -> bool:
        """
        Removes a single instance of the specified element from this queue,
        if it is present.  More formally, removes an element `e` such
        that `o.equals(e)`, if this queue contains one or more such
        elements.
        Returns `True` if this queue contained the specified element
        (or equivalently, if this queue changed as a result of the call).

        Arguments
        - o: element to be removed from this queue, if present

        Returns
        - `True` if this queue changed as a result of the call
        """
        ...


    def addAll(self, c: Iterable["E"]) -> bool:
        """
        Appends all of the elements in the specified collection to the end of
        this queue, in the order that they are returned by the specified
        collection's iterator.  Attempts to `addAll` of a queue to
        itself result in `IllegalArgumentException`.

        Arguments
        - c: the elements to be inserted into this queue

        Returns
        - `True` if this queue changed as a result of the call

        Raises
        - NullPointerException: if the specified collection or any
                of its elements are null
        - IllegalArgumentException: if the collection is this queue
        """
        ...


    def toString(self) -> str:
        ...


    def toArray(self) -> list["Object"]:
        """
        Returns an array containing all of the elements in this queue, in
        proper sequence.
        
        The returned array will be "safe" in that no references to it are
        maintained by this queue.  (In other words, this method must allocate
        a new array).  The caller is thus free to modify the returned array.
        
        This method acts as bridge between array-based and collection-based
        APIs.

        Returns
        - an array containing all of the elements in this queue
        """
        ...


    def toArray(self, a: list["T"]) -> list["T"]:
        """
        Returns an array containing all of the elements in this queue, in
        proper sequence; the runtime type of the returned array is that of
        the specified array.  If the queue fits in the specified array, it
        is returned therein.  Otherwise, a new array is allocated with the
        runtime type of the specified array and the size of this queue.
        
        If this queue fits in the specified array with room to spare
        (i.e., the array has more elements than this queue), the element in
        the array immediately following the end of the queue is set to
        `null`.
        
        Like the .toArray() method, this method acts as bridge between
        array-based and collection-based APIs.  Further, this method allows
        precise control over the runtime type of the output array, and may,
        under certain circumstances, be used to save allocation costs.
        
        Suppose `x` is a queue known to contain only strings.
        The following code can be used to dump the queue into a newly
        allocated array of `String`:
        
        ``` `String[] y = x.toArray(new String[0]);````
        
        Note that `toArray(new Object[0])` is identical in function to
        `toArray()`.

        Arguments
        - a: the array into which the elements of the queue are to
                 be stored, if it is big enough; otherwise, a new array of the
                 same runtime type is allocated for this purpose

        Returns
        - an array containing all of the elements in this queue

        Raises
        - ArrayStoreException: if the runtime type of the specified array
                is not a supertype of the runtime type of every element in
                this queue
        - NullPointerException: if the specified array is null
        """
        ...


    def iterator(self) -> Iterator["E"]:
        """
        Returns an iterator over the elements in this queue in proper sequence.
        The elements will be returned in order from first (head) to last (tail).
        
        The returned iterator is
        <a href="package-summary.html#Weakly">*weakly consistent*</a>.

        Returns
        - an iterator over the elements in this queue in proper sequence
        """
        ...


    def spliterator(self) -> "Spliterator"["E"]:
        """
        Returns a Spliterator over the elements in this queue.
        
        The returned spliterator is
        <a href="package-summary.html#Weakly">*weakly consistent*</a>.
        
        The `Spliterator` reports Spliterator.CONCURRENT,
        Spliterator.ORDERED, and Spliterator.NONNULL.

        Returns
        - a `Spliterator` over the elements in this queue

        Since
        - 1.8

        Unknown Tags
        - The `Spliterator` implements `trySplit` to permit limited
        parallelism.
        """
        ...


    def removeIf(self, filter: "Predicate"["E"]) -> bool:
        """
        Raises
        - NullPointerException: 
        """
        ...


    def removeAll(self, c: Iterable[Any]) -> bool:
        """
        Raises
        - NullPointerException: 
        """
        ...


    def retainAll(self, c: Iterable[Any]) -> bool:
        """
        Raises
        - NullPointerException: 
        """
        ...


    def clear(self) -> None:
        ...


    def forEach(self, action: "Consumer"["E"]) -> None:
        """
        Raises
        - NullPointerException: 
        """
        ...



from .FileSystems import FileSystems
from .Paths import Paths
from .SecureDirectoryStream import SecureDirectoryStream
from .DirectoryIteratorException import DirectoryIteratorException
from .DirectoryStream import DirectoryStream
from .FileAlreadyExistsException import FileAlreadyExistsException
from .FileSystemException import FileSystemException
from .Files import Files
from .LinkOption import LinkOption
from .NoSuchFileException import NoSuchFileException
from .NotDirectoryException import NotDirectoryException
from .OpenOption import OpenOption
from .Path import Path
from .StandardOpenOption import StandardOpenOption


"""
Python module generated from Java source file java.util.concurrent.SynchronousQueue

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.invoke import MethodHandles
from java.lang.invoke import VarHandle
from java.util import AbstractQueue
from java.util import Collections
from java.util import Iterator
from java.util import Objects
from java.util import Spliterator
from java.util.concurrent import *
from java.util.concurrent.locks import LockSupport
from java.util.concurrent.locks import ReentrantLock
from typing import Any, Callable, Iterable, Tuple


class SynchronousQueue(AbstractQueue, BlockingQueue, Serializable):
    """
    A BlockingQueue blocking queue in which each insert
    operation must wait for a corresponding remove operation by another
    thread, and vice versa.  A synchronous queue does not have any
    internal capacity, not even a capacity of one.  You cannot
    `peek` at a synchronous queue because an element is only
    present when you try to remove it; you cannot insert an element
    (using any method) unless another thread is trying to remove it;
    you cannot iterate as there is nothing to iterate.  The
    *head* of the queue is the element that the first queued
    inserting thread is trying to add to the queue; if there is no such
    queued thread then no element is available for removal and
    `poll()` will return `null`.  For purposes of other
    `Collection` methods (for example `contains`), a
    `SynchronousQueue` acts as an empty collection.  This queue
    does not permit `null` elements.
    
    Synchronous queues are similar to rendezvous channels used in
    CSP and Ada. They are well suited for handoff designs, in which an
    object running in one thread must sync up with an object running
    in another thread in order to hand it some information, event, or
    task.
    
    This class supports an optional fairness policy for ordering
    waiting producer and consumer threads.  By default, this ordering
    is not guaranteed. However, a queue constructed with fairness set
    to `True` grants threads access in FIFO order.
    
    This class and its iterator implement all of the *optional*
    methods of the Collection and Iterator interfaces.
    
    This class is a member of the
    <a href="/java.base/java/util/package-summary.html#CollectionsFramework">
    Java Collections Framework</a>.
    
    Type `<E>`: the type of elements held in this queue

    Author(s)
    - Doug Lea and Bill Scherer and Michael Scott

    Since
    - 1.5
    """

    def __init__(self):
        """
        Creates a `SynchronousQueue` with nonfair access policy.
        """
        ...


    def __init__(self, fair: bool):
        """
        Creates a `SynchronousQueue` with the specified fairness policy.

        Arguments
        - fair: if True, waiting threads contend in FIFO order for
               access; otherwise the order is unspecified.
        """
        ...


    def put(self, e: "E") -> None:
        """
        Adds the specified element to this queue, waiting if necessary for
        another thread to receive it.

        Raises
        - InterruptedException: 
        - NullPointerException: 
        """
        ...


    def offer(self, e: "E", timeout: int, unit: "TimeUnit") -> bool:
        """
        Inserts the specified element into this queue, waiting if necessary
        up to the specified wait time for another thread to receive it.

        Returns
        - `True` if successful, or `False` if the
                specified waiting time elapses before a consumer appears

        Raises
        - InterruptedException: 
        - NullPointerException: 
        """
        ...


    def offer(self, e: "E") -> bool:
        """
        Inserts the specified element into this queue, if another thread is
        waiting to receive it.

        Arguments
        - e: the element to add

        Returns
        - `True` if the element was added to this queue, else
                `False`

        Raises
        - NullPointerException: if the specified element is null
        """
        ...


    def take(self) -> "E":
        """
        Retrieves and removes the head of this queue, waiting if necessary
        for another thread to insert it.

        Returns
        - the head of this queue

        Raises
        - InterruptedException: 
        """
        ...


    def poll(self, timeout: int, unit: "TimeUnit") -> "E":
        """
        Retrieves and removes the head of this queue, waiting
        if necessary up to the specified wait time, for another thread
        to insert it.

        Returns
        - the head of this queue, or `null` if the
                specified waiting time elapses before an element is present

        Raises
        - InterruptedException: 
        """
        ...


    def poll(self) -> "E":
        """
        Retrieves and removes the head of this queue, if another thread
        is currently making an element available.

        Returns
        - the head of this queue, or `null` if no
                element is available
        """
        ...


    def isEmpty(self) -> bool:
        """
        Always returns `True`.
        A `SynchronousQueue` has no internal capacity.

        Returns
        - `True`
        """
        ...


    def size(self) -> int:
        """
        Always returns zero.
        A `SynchronousQueue` has no internal capacity.

        Returns
        - zero
        """
        ...


    def remainingCapacity(self) -> int:
        """
        Always returns zero.
        A `SynchronousQueue` has no internal capacity.

        Returns
        - zero
        """
        ...


    def clear(self) -> None:
        """
        Does nothing.
        A `SynchronousQueue` has no internal capacity.
        """
        ...


    def contains(self, o: "Object") -> bool:
        """
        Always returns `False`.
        A `SynchronousQueue` has no internal capacity.

        Arguments
        - o: the element

        Returns
        - `False`
        """
        ...


    def remove(self, o: "Object") -> bool:
        """
        Always returns `False`.
        A `SynchronousQueue` has no internal capacity.

        Arguments
        - o: the element to remove

        Returns
        - `False`
        """
        ...


    def containsAll(self, c: Iterable[Any]) -> bool:
        """
        Returns `False` unless the given collection is empty.
        A `SynchronousQueue` has no internal capacity.

        Arguments
        - c: the collection

        Returns
        - `False` unless given collection is empty
        """
        ...


    def removeAll(self, c: Iterable[Any]) -> bool:
        """
        Always returns `False`.
        A `SynchronousQueue` has no internal capacity.

        Arguments
        - c: the collection

        Returns
        - `False`
        """
        ...


    def retainAll(self, c: Iterable[Any]) -> bool:
        """
        Always returns `False`.
        A `SynchronousQueue` has no internal capacity.

        Arguments
        - c: the collection

        Returns
        - `False`
        """
        ...


    def peek(self) -> "E":
        """
        Always returns `null`.
        A `SynchronousQueue` does not return elements
        unless actively waited on.

        Returns
        - `null`
        """
        ...


    def iterator(self) -> Iterator["E"]:
        """
        Returns an empty iterator in which `hasNext` always returns
        `False`.

        Returns
        - an empty iterator
        """
        ...


    def spliterator(self) -> "Spliterator"["E"]:
        """
        Returns an empty spliterator in which calls to
        Spliterator.trySplit() trySplit always return `null`.

        Returns
        - an empty spliterator

        Since
        - 1.8
        """
        ...


    def toArray(self) -> list["Object"]:
        """
        Returns a zero-length array.

        Returns
        - a zero-length array
        """
        ...


    def toArray(self, a: list["T"]) -> list["T"]:
        """
        Sets the zeroth element of the specified array to `null`
        (if the array has non-zero length) and returns it.

        Arguments
        - a: the array

        Returns
        - the specified array

        Raises
        - NullPointerException: if the specified array is null
        """
        ...


    def toString(self) -> str:
        """
        Always returns `"[]"`.

        Returns
        - `"[]"`
        """
        ...


    def drainTo(self, c: Iterable["E"]) -> int:
        """
        Raises
        - UnsupportedOperationException: 
        - ClassCastException: 
        - NullPointerException: 
        - IllegalArgumentException: 
        """
        ...


    def drainTo(self, c: Iterable["E"], maxElements: int) -> int:
        """
        Raises
        - UnsupportedOperationException: 
        - ClassCastException: 
        - NullPointerException: 
        - IllegalArgumentException: 
        """
        ...



"""
Python module generated from Java source file org.bukkit.configuration.file.FileConfiguration

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Charsets
from com.google.common.base import Preconditions
from com.google.common.io import Files
from java.io import BufferedReader
from java.io import File
from java.io import FileInputStream
from java.io import FileNotFoundException
from java.io import FileOutputStream
from java.io import IOException
from java.io import InputStreamReader
from java.io import OutputStreamWriter
from java.io import Reader
from java.io import Writer
from org.bukkit.configuration import Configuration
from org.bukkit.configuration import InvalidConfigurationException
from org.bukkit.configuration import MemoryConfiguration
from org.bukkit.configuration.file import *
from typing import Any, Callable, Iterable, Tuple


class FileConfiguration(MemoryConfiguration):
    """
    This is a base class for all File based implementations of Configuration
    """

    def __init__(self):
        """
        Creates an empty FileConfiguration with no default values.
        """
        ...


    def __init__(self, defaults: "Configuration"):
        """
        Creates an empty FileConfiguration using the specified Configuration as a source for all default values.

        Arguments
        - defaults: Default value provider
        """
        ...


    def save(self, file: "File") -> None:
        """
        Saves this FileConfiguration to the specified location.
        
        If the file does not exist, it will be created. If already exists, it
        will be overwritten. If it cannot be overwritten or created, an
        exception will be thrown.
        
        This method will save using the system default encoding, or possibly
        using UTF8.

        Arguments
        - file: File to save to.

        Raises
        - IOException: Thrown when the given file cannot be written to for
            any reason.
        - IllegalArgumentException: Thrown when file is null.
        """
        ...


    def save(self, file: str) -> None:
        """
        Saves this FileConfiguration to the specified location.
        
        If the file does not exist, it will be created. If already exists, it
        will be overwritten. If it cannot be overwritten or created, an
        exception will be thrown.
        
        This method will save using the system default encoding, or possibly
        using UTF8.

        Arguments
        - file: File to save to.

        Raises
        - IOException: Thrown when the given file cannot be written to for
            any reason.
        - IllegalArgumentException: Thrown when file is null.
        """
        ...


    def saveToString(self) -> str:
        """
        Saves this FileConfiguration to a string, and returns it.

        Returns
        - String containing this configuration.
        """
        ...


    def load(self, file: "File") -> None:
        """
        Loads this FileConfiguration from the specified location.
        
        All the values contained within this configuration will be removed,
        leaving only settings and defaults, and the new values will be loaded
        from the given file.
        
        If the file cannot be loaded for any reason, an exception will be
        thrown.

        Arguments
        - file: File to load from.

        Raises
        - FileNotFoundException: Thrown when the given file cannot be
            opened.
        - IOException: Thrown when the given file cannot be read.
        - InvalidConfigurationException: Thrown when the given file is not
            a valid Configuration.
        - IllegalArgumentException: Thrown when file is null.
        """
        ...


    def load(self, reader: "Reader") -> None:
        """
        Loads this FileConfiguration from the specified reader.
        
        All the values contained within this configuration will be removed,
        leaving only settings and defaults, and the new values will be loaded
        from the given stream.

        Arguments
        - reader: the reader to load from

        Raises
        - IOException: thrown when underlying reader throws an IOException
        - InvalidConfigurationException: thrown when the reader does not
             represent a valid Configuration
        - IllegalArgumentException: thrown when reader is null
        """
        ...


    def load(self, file: str) -> None:
        """
        Loads this FileConfiguration from the specified location.
        
        All the values contained within this configuration will be removed,
        leaving only settings and defaults, and the new values will be loaded
        from the given file.
        
        If the file cannot be loaded for any reason, an exception will be
        thrown.

        Arguments
        - file: File to load from.

        Raises
        - FileNotFoundException: Thrown when the given file cannot be
            opened.
        - IOException: Thrown when the given file cannot be read.
        - InvalidConfigurationException: Thrown when the given file is not
            a valid Configuration.
        - IllegalArgumentException: Thrown when file is null.
        """
        ...


    def loadFromString(self, contents: str) -> None:
        """
        Loads this FileConfiguration from the specified string, as
        opposed to from file.
        
        All the values contained within this configuration will be removed,
        leaving only settings and defaults, and the new values will be loaded
        from the given string.
        
        If the string is invalid in any way, an exception will be thrown.

        Arguments
        - contents: Contents of a Configuration to load.

        Raises
        - InvalidConfigurationException: Thrown if the specified string is
            invalid.
        - IllegalArgumentException: Thrown if contents is null.
        """
        ...


    def options(self) -> "FileConfigurationOptions":
        ...



"""
Python module generated from Java source file com.google.common.graph.MutableNetwork

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.graph import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from typing import Any, Callable, Iterable, Tuple


class MutableNetwork(Network):
    """
    A subinterface of Network which adds mutation methods. When mutation is not required,
    users should prefer the Network interface.
    
    Type `<N>`: Node parameter type
    
    Type `<E>`: Edge parameter type

    Author(s)
    - Joshua O'Madadhain

    Since
    - 20.0
    """

    def addNode(self, node: "N") -> bool:
        """
        Adds `node` if it is not already present.
        
        **Nodes must be unique**, just as `Map` keys must be. They must also be non-null.

        Returns
        - `True` if the network was modified as a result of this call
        """
        ...


    def addEdge(self, nodeU: "N", nodeV: "N", edge: "E") -> bool:
        """
        Adds `edge` connecting `nodeU` to `nodeV`.
        
        If the graph is directed, `edge` will be directed in this graph; otherwise, it will be
        undirected.
        
        **`edge` must be unique to this graph**, just as a `Map` key must be. It must
        also be non-null.
        
        If `nodeU` and `nodeV` are not already present in this graph, this method will
        silently .addNode(Object) add `nodeU` and `nodeV` to the graph.
        
        If `edge` already connects `nodeU` to `nodeV` (in the specified order if
        this network .isDirected(), else in any order), then this method will have no effect.

        Returns
        - `True` if the network was modified as a result of this call

        Raises
        - IllegalArgumentException: if `edge` already exists in the graph and does not
            connect `nodeU` to `nodeV`
        - IllegalArgumentException: if the introduction of the edge would violate .allowsParallelEdges() or .allowsSelfLoops()
        """
        ...


    def addEdge(self, endpoints: "EndpointPair"["N"], edge: "E") -> bool:
        """
        Adds `edge` connecting `endpoints`. In an undirected network, `edge` will
        also connect `nodeV` to `nodeU`.
        
        If this graph is directed, `edge` will be directed in this graph; if it is undirected,
        `edge` will be undirected in this graph.
        
        If this graph is directed, `endpoints` must be ordered.
        
        **`edge` must be unique to this graph**, just as a `Map` key must be. It must
        also be non-null.
        
        If either or both endpoints are not already present in this graph, this method will silently
        .addNode(Object) add each missing endpoint to the graph.
        
        If `edge` already connects an endpoint pair equal to `endpoints`, then this
        method will have no effect.

        Returns
        - `True` if the network was modified as a result of this call

        Raises
        - IllegalArgumentException: if `edge` already exists in the graph and connects some
            other endpoint pair that is not equal to `endpoints`
        - IllegalArgumentException: if the introduction of the edge would violate .allowsParallelEdges() or .allowsSelfLoops()
        - IllegalArgumentException: if the endpoints are unordered and the graph is directed

        Since
        - 27.1
        """
        ...


    def removeNode(self, node: "N") -> bool:
        """
        Removes `node` if it is present; all edges incident to `node` will also be removed.

        Returns
        - `True` if the network was modified as a result of this call
        """
        ...


    def removeEdge(self, edge: "E") -> bool:
        """
        Removes `edge` from this network, if it is present.

        Returns
        - `True` if the network was modified as a result of this call
        """
        ...



from .CherryChestBoat import CherryChestBoat
from .AcaciaChestBoat import AcaciaChestBoat
from .BirchBoat import BirchBoat
from .CherryBoat import CherryBoat
from .JungleChestBoat import JungleChestBoat
from .SpruceChestBoat import SpruceChestBoat
from .PaleOakChestBoat import PaleOakChestBoat
from .BirchChestBoat import BirchChestBoat
from .BambooRaft import BambooRaft
from .OakBoat import OakBoat
from .JungleBoat import JungleBoat
from .MangroveBoat import MangroveBoat
from .AcaciaBoat import AcaciaBoat
from .PaleOakBoat import PaleOakBoat
from .DarkOakBoat import DarkOakBoat
from .BambooChestRaft import BambooChestRaft
from .DarkOakChestBoat import DarkOakChestBoat
from .MangroveChestBoat import MangroveChestBoat
from .SpruceBoat import SpruceBoat
from .OakChestBoat import OakChestBoat


"""
Python module generated from Java source file com.google.common.util.concurrent.Partially

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.util.concurrent import *
from typing import Any, Callable, Iterable, Tuple


class Partially:
    """
    Outer class that exists solely to let us write `Partially.GwtIncompatible` instead of plain
    `GwtIncompatible`. This is more accurate for Futures.catching, which is available
    under GWT but with a slightly different signature.
    
    We can't use `PartiallyGwtIncompatible` because then the GWT compiler wouldn't recognize
    it as a `GwtIncompatible` annotation. And for `Futures.catching`, we need the GWT
    compiler to autostrip the normal server method in order to expose the special, inherited GWT
    version.
    """





"""
Python module generated from Java source file com.google.thirdparty.publicsuffix.TrieParser

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.base import Joiner
from com.google.common.collect import ImmutableMap
from com.google.thirdparty.publicsuffix import *
from java.util import Deque
from typing import Any, Callable, Iterable, Tuple


class TrieParser:
    """
    Parser for a map of reversed domain names stored as a serialized radix tree.
    """





"""
Python module generated from Java source file org.bukkit.event.server.ServerLoadEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.event import HandlerList
from org.bukkit.event.server import *
from typing import Any, Callable, Iterable, Tuple


class ServerLoadEvent(ServerEvent):
    """
    This event is called when either the server startup or reload has completed.
    """

    def __init__(self, type: "LoadType"):
        """
        Creates a `ServerLoadEvent` with a given loading type.

        Arguments
        - type: the context in which the server was loaded
        """
        ...


    def getType(self) -> "LoadType":
        """
        Gets the context in which the server was loaded.

        Returns
        - the context in which the server was loaded
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class LoadType(Enum):
        """
        Represents the context in which the enclosing event has been completed.
        """

        STARTUP = 0
        RELOAD = 1



"""
Python module generated from Java source file com.google.common.util.concurrent.WrappingScheduledExecutorService

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.util.concurrent import *
from java.util.concurrent import Callable
from java.util.concurrent import ScheduledExecutorService
from java.util.concurrent import ScheduledFuture
from java.util.concurrent import TimeUnit
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class WrappingScheduledExecutorService(WrappingExecutorService, ScheduledExecutorService):
    """
    An abstract `ScheduledExecutorService` that allows subclasses to .wrapTask(Callable) wrap tasks before they are submitted to the underlying executor.
    
    Note that task wrapping may occur even if the task is never executed.

    Author(s)
    - Luke Sandberg
    """

    def schedule(self, command: "Runnable", delay: int, unit: "TimeUnit") -> "ScheduledFuture"[Any]:
        ...


    def schedule(self, task: "Callable"["V"], delay: int, unit: "TimeUnit") -> "ScheduledFuture"["V"]:
        ...


    def scheduleAtFixedRate(self, command: "Runnable", initialDelay: int, period: int, unit: "TimeUnit") -> "ScheduledFuture"[Any]:
        ...


    def scheduleWithFixedDelay(self, command: "Runnable", initialDelay: int, delay: int, unit: "TimeUnit") -> "ScheduledFuture"[Any]:
        ...



"""
Python module generated from Java source file org.bukkit.Statistic

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from java.util import Locale
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class Statistic(Enum):
    """
    Represents a countable statistic, which is tracked by the server.
    """

    DAMAGE_DEALT = 0
    DAMAGE_TAKEN = 1
    DEATHS = 2
    MOB_KILLS = 3
    PLAYER_KILLS = 4
    FISH_CAUGHT = 5
    ANIMALS_BRED = 6
    LEAVE_GAME = 7
    JUMP = 8
    DROP_COUNT = 9
    DROP = (Type.ITEM)
    PICKUP = (Type.ITEM)
    PLAY_ONE_MINUTE = 12
    """
    Name is misleading, actually records ticks played.
    """
    TOTAL_WORLD_TIME = 13
    WALK_ONE_CM = 14
    WALK_ON_WATER_ONE_CM = 15
    FALL_ONE_CM = 16
    SNEAK_TIME = 17
    CLIMB_ONE_CM = 18
    FLY_ONE_CM = 19
    WALK_UNDER_WATER_ONE_CM = 20
    MINECART_ONE_CM = 21
    BOAT_ONE_CM = 22
    PIG_ONE_CM = 23
    HORSE_ONE_CM = 24
    SPRINT_ONE_CM = 25
    CROUCH_ONE_CM = 26
    AVIATE_ONE_CM = 27
    MINE_BLOCK = (Type.BLOCK)
    USE_ITEM = (Type.ITEM)
    BREAK_ITEM = (Type.ITEM)
    CRAFT_ITEM = (Type.ITEM)
    KILL_ENTITY = (Type.ENTITY)
    ENTITY_KILLED_BY = (Type.ENTITY)
    TIME_SINCE_DEATH = 34
    TALKED_TO_VILLAGER = 35
    TRADED_WITH_VILLAGER = 36
    CAKE_SLICES_EATEN = 37
    CAULDRON_FILLED = 38
    CAULDRON_USED = 39
    ARMOR_CLEANED = 40
    BANNER_CLEANED = 41
    BREWINGSTAND_INTERACTION = 42
    BEACON_INTERACTION = 43
    DROPPER_INSPECTED = 44
    HOPPER_INSPECTED = 45
    DISPENSER_INSPECTED = 46
    NOTEBLOCK_PLAYED = 47
    NOTEBLOCK_TUNED = 48
    FLOWER_POTTED = 49
    TRAPPED_CHEST_TRIGGERED = 50
    ENDERCHEST_OPENED = 51
    ITEM_ENCHANTED = 52
    RECORD_PLAYED = 53
    FURNACE_INTERACTION = 54
    CRAFTING_TABLE_INTERACTION = 55
    CHEST_OPENED = 56
    SLEEP_IN_BED = 57
    SHULKER_BOX_OPENED = 58
    TIME_SINCE_REST = 59
    SWIM_ONE_CM = 60
    DAMAGE_DEALT_ABSORBED = 61
    DAMAGE_DEALT_RESISTED = 62
    DAMAGE_BLOCKED_BY_SHIELD = 63
    DAMAGE_ABSORBED = 64
    DAMAGE_RESISTED = 65
    CLEAN_SHULKER_BOX = 66
    OPEN_BARREL = 67
    INTERACT_WITH_BLAST_FURNACE = 68
    INTERACT_WITH_SMOKER = 69
    INTERACT_WITH_LECTERN = 70
    INTERACT_WITH_CAMPFIRE = 71
    INTERACT_WITH_CARTOGRAPHY_TABLE = 72
    INTERACT_WITH_LOOM = 73
    INTERACT_WITH_STONECUTTER = 74
    BELL_RING = 75
    RAID_TRIGGER = 76
    RAID_WIN = 77
    INTERACT_WITH_ANVIL = 78
    INTERACT_WITH_GRINDSTONE = 79
    TARGET_HIT = 80
    INTERACT_WITH_SMITHING_TABLE = 81
    STRIDER_ONE_CM = 82


    def getType(self) -> "Type":
        """
        Gets the type of this statistic.

        Returns
        - the type of this statistic
        """
        ...


    def isSubstatistic(self) -> bool:
        """
        Checks if this is a substatistic.
        
        A substatistic exists en masse for each block, item, or entitytype, depending on
        .getType().
        
        This is a redundant method and equivalent to checking
        `getType() != Type.UNTYPED`

        Returns
        - True if this is a substatistic
        """
        ...


    def isBlock(self) -> bool:
        """
        Checks if this is a substatistic dealing with blocks.
        
        This is a redundant method and equivalent to checking
        `getType() == Type.BLOCK`

        Returns
        - True if this deals with blocks
        """
        ...


    def getKey(self) -> "NamespacedKey":
        ...


    class Type(Enum):
        """
        The type of statistic.
        """

        UNTYPED = 0
        """
        Statistics of this type do not require a qualifier.
        """
        ITEM = 1
        """
        Statistics of this type require an Item Material qualifier.
        """
        BLOCK = 2
        """
        Statistics of this type require a Block Material qualifier.
        """
        ENTITY = 3
        """
        Statistics of this type require an EntityType qualifier.
        """
